tree grammar DSLRecCreator;

options {
  language = Java;
  output = AST;
  tokenVocab = DSL;
  ASTLabelType = SpcAST;
  rewrite=false;
}

@treeparser::header {
package dsl.antlr;

import dsl.SpcAST;
import recommendation.RecommendationBuilder;
import recommendation.ScenarioBuilder;
import recommendation.asset.AssetBuilder;
import value.valueData.ValueType;
import dsl.DSLUtil;
import attribute.AttributeBuilder;
}

@members {
private RecommendationBuilder recBuilder = new RecommendationBuilder();

public RecommendationBuilder getRecBuilder() {
    return recBuilder;
}

}

recommendation
    :
    ^(REC {recBuilder.setName($REC.text);} 
      statement+)
    ;
    
statement
    :
      category
    | summary
    | description
    | scenario
    | asset {AssetBuilder assetBuilder = $asset.assetBuilder;
             if(assetBuilder != null) {
                recBuilder.addAsset(assetBuilder.buildAsset());
             }
            }
    ;
    
category
    :
    CATEGORY {recBuilder.addCategory($CATEGORY.text);}
    ;
    
summary
    :
    SUMMARY {recBuilder.setSummary($SUMMARY.text);}
    ;
    
description
    :
    DESC {recBuilder.setDescription($DESC.text);}
    ;
    
asset returns [AssetBuilder assetBuilder]
@init {
  AssetBuilder assetBuilder = new AssetBuilder();
}
    :
    ^(ASSET {assetBuilder.setIdentifier($ASSET.text);}
       TEXT { assetBuilder.setContent($TEXT.text);}) {$assetBuilder = assetBuilder;}
    ;
    
scenario
@init {
  ScenarioBuilder scenarioBuilder = new ScenarioBuilder();
}
@after {
  recBuilder.addScenario(scenarioBuilder.buildScenario());
}
    :
    ^(SCENARIO expressionList[scenarioBuilder] actionList[scenarioBuilder])
    ;

expressionList[ScenarioBuilder scenarioBuilder]
    :
    ^(GIVEN expression[scenarioBuilder]+)
    ;
actionList[ScenarioBuilder scenarioBuilder]
    :
    ^(THEN action[scenarioBuilder]+)
    ;
    
expression[ScenarioBuilder scenarioBuilder]
@init {
  AttributeBuilder attrBuilder = new AttributeBuilder();
}
@after {
	String name = retval.tree.getText();
	attrBuilder.setName(name);
	scenarioBuilder.addAttribute(attrBuilder.buildAttribute());
}
    :
    ^(EXPR operator[attrBuilder]+)
    ;
    
operator[AttributeBuilder attrBuilder]
@after {
  SpcAST opTree = retval.tree;
  int operator = opTree.getType();
  SpcAST val1Tree = opTree.leftChild();
  SpcAST val2Tree = opTree.rightChild();
  ValueType type = DSLUtil.getValueType(val1Tree.getType());
  String val1 = val1Tree.getText();
  
  String val2;
  if(val2Tree != null) {
    if(type != DSLUtil.getValueType(val2Tree.getType())) {
      throw new IllegalArgumentException("Values in ranges must be of the same type");
    }
    val2 = val2Tree.getText();
  } else {
    val2 = null;
  }
  attrBuilder.setType(type);
  attrBuilder.addValue(operator,val1, val2);
}
    :
    ^((EQL|NEQL|GT|LT|GTE|LTE|BETWEEN) value value?)
    ;
    
value
    :
    TEXT
    | INTEGER
    | TRUE
    | FALSE
    | STRING
    ;

action[ScenarioBuilder scenarioBuilder]
    :
    ADD {scenarioBuilder.addWeight(Integer.parseInt($ADD.text));}
    | REMOVE {scenarioBuilder.removeWeight(Integer.parseInt($REMOVE.text));}
    | STOP {scenarioBuilder.setStop(true);}
    | MAKE_REQ {scenarioBuilder.setRequired(true);}
    | NO_REC {scenarioBuilder.setNotRecommended(true);}
    | asset {AssetBuilder assetBuilder = $asset.assetBuilder;
             if(assetBuilder != null) {
                scenarioBuilder.addAsset(assetBuilder.buildAsset());
             }
            }
    ;