/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog;

import java.util.LinkedList;
import java.util.List;

/**
 * This class represents a set of user responses for a dialog.
 * It is basically a wrapped for a list.
 * 
 * @author jake todaro
 * 
 * @version 12/09/11
 */

public class AnswerSet {
	
	private final List<Answer> answers;
	
	/**
	 * constructor initializes the fields
	 */
	public AnswerSet(){
		answers = new LinkedList<Answer>();
	}
	
	/**
	 * add an answer to the answer set
	 * 
	 * @param answer - the answer to add to the answer set
	 */
	public void addAnswer(Answer answer){
		answers.add(answer);
	}
	
	/**
	 * determines if the given answer is in this answer set
	 * 
	 * @param answer - the answer to check for
	 * 
	 * @return true if the given answer is in the set, false otherwise
	 */
	public boolean contains(Answer answer){
		return answers.contains(answer);
	}
	
	/** return the Answer at the specified index
	 * 
	 * @param index - the index of the Answer to return
	 * @return the the Answer at the specified index
	 */
	public Answer getAnswer(int index){
		return answers.get(index);
	}

	/** return the number of Answers in this AnswerSet
	 * 
	 * @return the number of Answers in this AnswerSet
	 */
	public int getNumberOfAnswers(){
		return answers.size();
	}
	
	public String toString(){
		String result = "";
		
		for(int i = 0; i < answers.size(); i++){
			result += answers.get(i).toString() + "\n";
		}
		
		return result;
	}
}
