package booleanExpression;

import static org.junit.Assert.*;

import java.util.LinkedList;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import dialog.Answer;
import dialog.Dialog;
import dialog.Question;


public class BooleanExpressionTest {
	
	BooleanValue TRUE, FALSE;
	
	@Before
	public void setup(){
		TRUE = BooleanExpression.TRUE;
		FALSE = BooleanExpression.FALSE;
	}
	
	/** test the not BooleanExpression*/
	@Test
	public void testNot(){
		assertEquals(FALSE, BooleanExpression.not(TRUE));
		assertEquals(TRUE, BooleanExpression.not(FALSE)); 
	}
	
	
	/** test the not BooleanExpression for Answer BooleanValues*/
	@Test
	public void testNotForAnswers(){
		Dialog.createInstance();
		
		Question question = new Question(1, "q", null);
		Answer a1 = new Answer(1, "1", question);
		Answer a2 = new Answer(2, "2", question);
		Answer a3 = new Answer(3, "3", question);
		question.addAnswer(a1);
		question.addAnswer(a2);
		question.addAnswer(a3);
		
		assertEquals(FALSE, BooleanExpression.not(a3));
		
		Dialog.getAnswerSet().addAnswer(a2);
		
		assertEquals(FALSE, BooleanExpression.not(a2));
		assertEquals(TRUE, BooleanExpression.not(a3));
	}
	
	/** test that an and BooleanExpression with a single atom returns
	 * the correct value */
	@Test
	public void testAndSingleAtom(){
		List<BooleanValue> trueList = new LinkedList<BooleanValue>();
		trueList.add(TRUE);
		assertEquals(TRUE, BooleanExpression.and(trueList));
		
		List<BooleanValue> falseList = new LinkedList<BooleanValue>();
		falseList.add(BooleanExpression.FALSE);
		assertEquals(BooleanExpression.FALSE, BooleanExpression.and(falseList));
	}

	/** test that an BooleanExpression with a multiple atoms returns
	 * the correct value */
	@Test
	public void testAndMultipleAtoms(){
		List<BooleanValue> list = new LinkedList<BooleanValue>();
		list.add(TRUE);
		list.add(TRUE);
		assertEquals(TRUE, BooleanExpression.and(list));
		
		list.add(FALSE);
		assertEquals(FALSE, BooleanExpression.and(list));

		list.clear();
		list.add(FALSE);
		list.add(FALSE);
		assertEquals(FALSE, BooleanExpression.and(list));
	}
	
	/** test that an or BooleanExpression with a single atom returns
	 * the correct value */
	@Test
	public void testOrSingleAtom(){
		List<BooleanValue> trueList = new LinkedList<BooleanValue>();
		trueList.add(TRUE);
		assertEquals(TRUE, BooleanExpression.or(trueList));
		
		List<BooleanValue> falseList = new LinkedList<BooleanValue>();
		falseList.add(BooleanExpression.FALSE);
		assertEquals(BooleanExpression.FALSE, BooleanExpression.or(falseList));
	}

	/** test that an AndExpression with a multiple atoms returns
	 * the correct value */
	@Test
	public void testOrMultipleAtoms(){
		List<BooleanValue> list = new LinkedList<BooleanValue>();
		list.add(TRUE);
		list.add(TRUE);
		assertEquals(TRUE, BooleanExpression.or(list));
		
		list.add(FALSE);
		assertEquals(TRUE, BooleanExpression.or(list));
		
		list.clear();
		list.add(FALSE);
		list.add(FALSE);
		assertEquals(FALSE, BooleanExpression.or(list));
	}
}
