/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/
package configurator;

import java.util.LinkedList;
import java.util.List;

import asset.Asset;

import com.db4o.ObjectContainer;
import com.db4o.ObjectSet;

import database.AssetDatabase;
import dialog.AnswerSet;

/**
 * This asset selecting strategy chooses all of the assets that are
 * relevant to the users responses. If any of the users answers have a tag
 * that matches an asset's tag, the asset is return in the list.
 * 
 * @author jake todaro
 *
 */
public class FindAllRelevant implements AssetMatcher{
	
	public FindAllRelevant(){}

	@Override
	public List<Asset> findRelevantAssets(AnswerSet answerSet) {
		
		List<String> allAnswerTags = answerSet.getAllAnswersAssetTags();
		
		ObjectContainer dboc = AssetDatabase.getObjectContainer();
		ObjectSet<Asset> assets = dboc.queryByExample(Asset.class);
		
		List<Asset> relevantAssets = new LinkedList<Asset>();
		
		for(int i = 0; i < assets.size(); i++){
			Asset asset = assets.get(i);
			List<String> assetTags = asset.getTags();
			for(int j = 0; j < assetTags.size(); j++){
				if(!relevantAssets.contains(asset) && allAnswerTags.contains(assetTags.get(j)))
					relevantAssets.add(asset);
			}
		}
		
		return relevantAssets;
	}

}
