/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog.trigger;

import java.util.List;

import dialog.Answer;
import dialog.Dialog;
import dialog.Question;

/** this class represents a NotTrigger. NotTriggers are a type
 * of Trigger. A NotTrigger holds an Answer that must not be selected.
 * A NotTrigger is not satisfied simply if the Answer is not in the AnswerSet.
 * The NotTrigger must check that the Question that the Answer belongs to was
 * asked and that it was answered with an Answer other then the Answer that
 * the NotTrigger has.
 * 
 * @author Jake Todaro
 * 
 * @version 12/09/11
 */

public class NotTrigger extends SimpleTrigger {
	
	/** constructor initializes the fields
	 * 
	 * @param answer - the answer that cannot be selected for this Trigger to be satisfied
	 */
	public NotTrigger (TriggerClause triggerClause){
		super(triggerClause);
	}
	
	@Override
	public boolean isSatisfied(){
		
		final TriggerClause triggerClause = getTriggerClause();
		
		if(triggerClause instanceof Answer){
	
			final Question parentQuestion = ((Answer)triggerClause).getParentQuestion();
			
			//the question must be asked and not have been answered a certain way
			//it is not sufficient enough to say return true if this answer is not in the answer set
			
			parentQuestion.getAnswerList().remove((Answer)triggerClause);
			final List<Answer> parentAnswers = parentQuestion.getAnswerList();
	
			//if any of these are in the answer set, the question was answered appropriately
			for(int i = 0; i < parentAnswers.size(); i++){
				if(Dialog.getAnswerSet().contains(parentAnswers.get(i))){
					return true;
				}
			}
			
			return false;
		}
		else{
			return !triggerClause.isSatisfied();
			
		}
	}

	public String toString(){
		return "Not " + triggerClauses.get(0).toString();
	}
}
