/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog.trigger;

import java.util.List;


/**
 * This class represents an "or" requirement. That is, this requirement is
 * satisfied if any of the Answers in its list have been chosen
 * 
 * @author jake todaro
 * 
 * @version 12/09/11
 */

public class OrTrigger extends Trigger {

	private final List<TriggerClause> ors;

	/**
	 * constructor initializes the fields
	 * 
	 * @param triggerClauses
	 *            - the List of Answers
	 */
	public OrTrigger(List<TriggerClause> triggerClauses) {
		ors = triggerClauses;
	}

	/**
	 * return a list of Answers in which only one must be present in the
	 * response set to satisfy this requirement
	 * 
	 * @return a list of Answers in which only one must be present in the
	 *         response set to satisfy this requirement
	 */
	public List<TriggerClause> getOrRequirements() {
		return ors;
	}

	@Override
	public boolean isSatisfied() {
		boolean met = false;
		for (int i = 0; i < this.getOrRequirements().size(); i++) {
			met = met || ors.get(i).isSatisfied(); 
		}

		return met;
	}
}
