/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog.trigger;

import java.util.LinkedList;
import java.util.List;


/** this abstract class represents a Trigger. Triggers belong to
 * Askable objects like Questions and SubDialogs. There are three types
 * of Triggers: SimpleTriggers, NotTriggers, and OrTriggers. See each
 * kind of Trigger for more information about them.
 * 
 * @author jake todaro
 * 
 * @version 12/15/11
 */
public abstract class Trigger implements TriggerClause{

	protected List<TriggerClause> triggerClauses;
	
	protected Trigger(){
		triggerClauses = new LinkedList<TriggerClause>();
	}
	
	/** determine if this Trigger is satisfied
	 * 
	 * @return true if this Trigger is Satisfied
	 */
	public abstract boolean isSatisfied();

}
