/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog.trigger;

import asset.WeightedObject;

/** this class represents a weighed TriggerClause. this clause
 * has a WeightedObject and a weight and is satisfied if the weight
 * of the WeightedObject has reached the specified weight.
 * 
 * @author jake todaro
 *
 * @version 12/15/11
 */

public class WeightedTriggerClause implements TriggerClause{
	
	private final WeightedObject weightedObject;
	private final double weight;
	
	/** constructor initializes the fields
	 * 
	 * @param weightedObject - the WeightedObject to consider
	 * @param weight - the weight that the WeightedObject must be 
	 * 	at for this TriggerClause to be satisfied
	 */
	public WeightedTriggerClause(WeightedObject weightedObject, double weight){
		this.weightedObject = weightedObject;
		this.weight = weight;
	}

	@Override
	public boolean isSatisfied() {
		return weightedObject.getWeight() <= weight;
	}
}
