/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package app;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.util.Collection;

import javax.swing.*;
import javax.swing.border.BevelBorder;
import javax.swing.event.*;
import javax.swing.table.DefaultTableModel;

import recommendation.*;
import recommendationView.RecommendationReconstructor;
import attribute.*;

import com.db4o.ext.Db4oIOException;

import database.*;

/**
 * A user interface for maintaining Recommendations and Attributes in the database
 * 
 * @author Wesley Ripley, Adam Talbot
 * @version Feb 28, 2013
 */
@SuppressWarnings("serial")
public class RecommendationTool extends JFrame implements ListSelectionListener, ActionListener{

	private Database db;
	private AttributeReference attrRef;
	//recommendations tab variables
	private JTextPane recInfoText;
	private JList recList;
	private DefaultListModel recListModel = new DefaultListModel();
	private JButton recAddButton, recEditButton, recDeleteButton;
	//attribute references variables
	private JTextPane attrInfoText;
	private JTable attrList;
	private DefaultTableModel attrListModel;
	private JButton attrAddButton, attrEditButton, attrDeleteButton;

	/**
	 * Constructor for RecommendationTool
	 * 
	 * Creates and displays JFrame ready for user interaction
	 */
	public RecommendationTool() {
		super("Recommendation Tool");
		try{
			db = SPC.setDB("SpcDB");
		} catch(Db4oIOException e) {
			JFileChooser fc = new JFileChooser();
			fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
			fc.setDialogTitle("Open Database File");
			int returnValue = fc.showOpenDialog(this);
			if(returnValue == JFileChooser.APPROVE_OPTION) {
				File dbFile = fc.getSelectedFile();
				db = new Db4oDatabase();
				db.use(dbFile.getAbsolutePath());
			} else {
				throw new RuntimeException("No Database File Provided");
			}
		}
		attrRef = db.getAttributeReference();
		
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setSize(691,536);
		 
		getContentPane().setLayout(new GridLayout(0, 1, 0, 0));
		
		JTabbedPane tabbedPane = new JTabbedPane(JTabbedPane.TOP);
		
		JPanel recPanel = new JPanel();
		tabbedPane.addTab("Recommendations", null, recPanel, null);
		recPanel.setLayout(new BorderLayout(0, 0));
		
		createRecommendationsTab(recPanel);

		JPanel attrPanel = new JPanel();
		tabbedPane.addTab("Attribute Reference", null, attrPanel, null);
		attrPanel.setLayout(new BorderLayout(0, 0));
		
		createAttributeReferenceTab(attrPanel);
		
		getContentPane().add(tabbedPane);
		setVisible(true);
	}
	
	/**
	 * Function to create the Recommendations Tab
	 * Created using WindowBuilder Pro
	 * @param recPanel
	 * 		The tabs JPanel where all components should be added
	 */
	private void createRecommendationsTab(JPanel recPanel) {
		JSplitPane splitPane = new JSplitPane();
		recPanel.add(splitPane, BorderLayout.CENTER);
		splitPane.setDividerLocation(200 + splitPane.getInsets().left);
		
		JPanel listPanel = new JPanel();
		listPanel.setBorder(new BevelBorder(BevelBorder.LOWERED, null, null, null, null));
		splitPane.setLeftComponent(listPanel);
		GridBagLayout gbl_listPanel = new GridBagLayout();
		gbl_listPanel.rowWeights = new double[]{0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
		gbl_listPanel.columnWeights = new double[]{1.0};
		listPanel.setLayout(gbl_listPanel);
		
		initializeRecList();
		recList =  new JList(recListModel);
		recList.addListSelectionListener(this);
		
		JScrollPane scrollPane = new JScrollPane(recList);
		scrollPane.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
		GridBagConstraints gbc_scrollPane = new GridBagConstraints();
		gbc_scrollPane.insets = new Insets(0, 0, 5, 0);
		gbc_scrollPane.fill = GridBagConstraints.BOTH;
		gbc_scrollPane.gridx = 0;
		gbc_scrollPane.gridy = 1;
		listPanel.add(scrollPane, gbc_scrollPane);
		
		
		recAddButton = new JButton("Add");
		recAddButton.addActionListener(this);
		GridBagConstraints gbc_btnAdd = new GridBagConstraints();
		gbc_btnAdd.anchor = GridBagConstraints.PAGE_END;
		gbc_btnAdd.fill = GridBagConstraints.VERTICAL;
		gbc_btnAdd.gridx = 0;
		gbc_btnAdd.gridy = 15;
		listPanel.add(recAddButton, gbc_btnAdd);
		
		JPanel infoPanel = new JPanel();
		infoPanel.setBorder(new BevelBorder(BevelBorder.LOWERED, null, null, null, null));
		splitPane.setRightComponent(infoPanel);
		GridBagLayout gbl_infoPanel = new GridBagLayout();
		gbl_infoPanel.rowWeights = new double[]{1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
		gbl_infoPanel.columnWeights = new double[]{1.0, 1.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0};
		infoPanel.setLayout(gbl_infoPanel);
		
		recInfoText = new JTextPane();
		recInfoText.setEditable(false);
		GridBagConstraints gbc_textPane = new GridBagConstraints();
		gbc_textPane.gridheight = 14;
		gbc_textPane.gridwidth = 11;
		gbc_textPane.insets = new Insets(0, 0, 5, 0);
		gbc_textPane.fill = GridBagConstraints.BOTH;
		gbc_textPane.gridx = 0;
		gbc_textPane.gridy = 0;
		infoPanel.add(recInfoText, gbc_textPane);
		
		recEditButton = new JButton("Edit");
		recEditButton.addActionListener(this);
		GridBagConstraints gbc_btnEdit = new GridBagConstraints();
		gbc_btnEdit.insets = new Insets(0, 0, 0, 5);
		gbc_btnEdit.gridx = 4;
		gbc_btnEdit.gridy = 14;
		infoPanel.add(recEditButton, gbc_btnEdit);
		
		recDeleteButton = new JButton("Delete");
		recDeleteButton.addActionListener(this);
		GridBagConstraints gbc_btnDelete = new GridBagConstraints();
		gbc_btnDelete.insets = new Insets(0, 0, 0, 5);
		gbc_btnDelete.gridx = 5;
		gbc_btnDelete.gridy = 14;
		infoPanel.add(recDeleteButton, gbc_btnDelete);
	}
	
	/**
	 * Function to create the Attribute Reference Tab
	 * Created using WindowBuilder Pro
	 * @param attrPanel
	 * 		The tabs JPanel where all components should be added
	 */
	private void createAttributeReferenceTab(JPanel attrPanel) {
		JSplitPane splitPane = new JSplitPane();
		attrPanel.add(splitPane, BorderLayout.CENTER);
		splitPane.setDividerLocation(200 + splitPane.getInsets().left);
		
		JPanel listPanel = new JPanel();
		listPanel.setBorder(new BevelBorder(BevelBorder.LOWERED, null, null, null, null));
		splitPane.setLeftComponent(listPanel);
		GridBagLayout gbl_listPanel = new GridBagLayout();
		gbl_listPanel.rowWeights = new double[]{0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
		gbl_listPanel.columnWeights = new double[]{1.0};
		//gbl_listPanel.columnWidths = new int[]{1, 0};
		//gbl_listPanel.rowHeights = new int[]{1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
		//gbl_listPanel.columnWeights = new double[]{1.0, Double.MIN_VALUE};
		//gbl_listPanel.rowWeights = new double[]{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, Double.MIN_VALUE};
		listPanel.setLayout(gbl_listPanel);
		
		attrList =  new JTable();
		attrList.setAutoCreateRowSorter(true);
		attrList.getSelectionModel().addListSelectionListener(this);
		initializeAttrList();
		
		JScrollPane scrollPane = new JScrollPane(attrList);
		scrollPane.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
		GridBagConstraints gbc_scrollPane = new GridBagConstraints();
		gbc_scrollPane.insets = new Insets(0, 0, 5, 0);
		gbc_scrollPane.fill = GridBagConstraints.BOTH;
		gbc_scrollPane.gridx = 0;
		gbc_scrollPane.gridy = 1;
		listPanel.add(scrollPane, gbc_scrollPane);
		
		
		attrAddButton = new JButton("Add");
		attrAddButton.addActionListener(this);
		GridBagConstraints gbc_btnAdd = new GridBagConstraints();
		gbc_btnAdd.anchor = GridBagConstraints.PAGE_END;
		gbc_btnAdd.fill = GridBagConstraints.VERTICAL;
		gbc_btnAdd.gridx = 0;
		gbc_btnAdd.gridy = 15;
		listPanel.add(attrAddButton, gbc_btnAdd);
		
		JPanel infoPanel = new JPanel();
		infoPanel.setBorder(new BevelBorder(BevelBorder.LOWERED, null, null, null, null));
		splitPane.setRightComponent(infoPanel);
		GridBagLayout gbl_infoPanel = new GridBagLayout();
		gbl_infoPanel.rowWeights = new double[]{1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
		gbl_infoPanel.columnWeights = new double[]{1.0, 1.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0};
		infoPanel.setLayout(gbl_infoPanel);
		
		attrInfoText = new JTextPane();
		attrInfoText.setEditable(false);
		GridBagConstraints gbc_textPane = new GridBagConstraints();
		gbc_textPane.gridheight = 14;
		gbc_textPane.gridwidth = 11;
		gbc_textPane.insets = new Insets(0, 0, 5, 0);
		gbc_textPane.fill = GridBagConstraints.BOTH;
		gbc_textPane.gridx = 0;
		gbc_textPane.gridy = 0;
		infoPanel.add(attrInfoText, gbc_textPane);
		
		attrEditButton = new JButton("Edit");
		attrEditButton.addActionListener(this);
		GridBagConstraints gbc_btnEdit = new GridBagConstraints();
		gbc_btnEdit.insets = new Insets(0, 0, 0, 5);
		gbc_btnEdit.gridx = 4;
		gbc_btnEdit.gridy = 14;
		infoPanel.add(attrEditButton, gbc_btnEdit);
		
		attrDeleteButton = new JButton("Delete");
		attrDeleteButton.addActionListener(this);
		GridBagConstraints gbc_btnDelete = new GridBagConstraints();
		gbc_btnDelete.insets = new Insets(0, 0, 0, 5);
		gbc_btnDelete.gridx = 5;
		gbc_btnDelete.gridy = 14;
		infoPanel.add(attrDeleteButton, gbc_btnDelete);
	}
	
	/**
	 * Reset the list of recommendations
	 */
	private void initializeRecList() {
		Collection<Recommendation> recs = db.getAllRecommendations();
		recListModel.clear();
		for(Recommendation rec : recs) {
			recListModel.addElement(rec);
		}
		return;
	}
	
	/**
	 * Reset the list of attributes
	 */
	private void initializeAttrList() {
		attrListModel = new DefaultTableModel();
		attrListModel.addColumn("Name");
		attrListModel.addColumn("Type");
		Collection<AttributeDescription> attrs = attrRef.getAllAvaiableAttrs();
		for(AttributeDescription attr : attrs) {
			String[] newRow = {attr.getName(), attr.getType().toString()};
			attrListModel.addRow(newRow);
		}
		attrList.setModel(attrListModel);
		return;
	}

	/**
	 * Method to handle users selection of an item in one of the lists.
	 * 
	 * Updates the right hand side to reflect selection
	 */
	@Override
	public void valueChanged(ListSelectionEvent e) {
		if(e.getSource() == recList && somethingSelected(false)) {
			Recommendation selected = (Recommendation)recListModel.getElementAt(recList.getSelectedIndex());
			recInfoText.setText("Name: "+selected.getName()+"\n\nSummary:\n"+selected.getSummary()+"\n\nDescription:\n"+selected.getDescription());
		} else if(somethingSelected(true)){
			String attrName = getSelectedAttr();
			AttributeDescription selected = attrRef.getAttr(attrName);
			attrInfoText.setText("Name: "+selected.getName()+"\n\nType: "+selected.getType()+"\n\nDescription:\n"+selected.getDescription());
		}
	}
	
	public static void main(String[] args) {
		@SuppressWarnings("unused")
		RecommendationTool recLoader = new RecommendationTool();
	}

	/**
	 * Method called when any button is pressed
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == recAddButton) {
			//open the recommendation loader
			new RecommendationLoader(db,this,true);
			initializeRecList();
		} else if(e.getSource() == recEditButton && somethingSelected(false)) {
			BasicRecommendation selected = (BasicRecommendation)recListModel.getElementAt(recList.getSelectedIndex());
			// reconstruct the recommendation into a file
			RecommendationReconstructor reconstructor = new RecommendationReconstructor(selected);
			File recFile = new File(reconstructor.reconstruct());
			boolean fileOpened = true;
			try {
				Desktop.getDesktop().open(recFile);
			} catch (IOException e1) {
				JOptionPane.showMessageDialog(this,
					    "Recommendation file: "+recFile+" could not be opened!",
					    "Open Error",
					    JOptionPane.ERROR_MESSAGE);
				fileOpened = false;
				e1.printStackTrace();
			}
			if(fileOpened) {
				//open recommendation loader for editing
				new RecommendationLoader(db,this,true,recFile);
			}
			initializeRecList();
			recInfoText.setText("");
		}else if(e.getSource() == recDeleteButton && somethingSelected(false)) {
			Recommendation selected = (Recommendation)recListModel.getElementAt(recList.getSelectedIndex());
			//delete recommendation
			db.delete(selected);
			initializeRecList();
		} else if(e.getSource() == attrAddButton) {
			//open attribute editor
			new AttributeEditor(db,this,true);
			initializeAttrList();
		} else if(e.getSource() == attrEditButton && somethingSelected(true)) {
			String attrName = getSelectedAttr();
			//open attribute editor in edit mode
			new AttributeEditor(db,this,true,attrName);
			initializeAttrList();
		} else if(e.getSource() == attrDeleteButton && somethingSelected(true)) {
			String attrName = getSelectedAttr();
			//delete attribute
			attrRef.removeAttribute(attrName);
			db.store(attrRef);
			initializeAttrList();
		}
	}
	
	/**
	 * Determines if something is selected in one of the lists
	 * @param attr
	 * 		Which list to check. True means attribute list, False means recommendation list
	 * @return
	 * 		True if something is selected, false otherwise
	 */
	private boolean somethingSelected(boolean attr) {
		if(attr) {
			return attrList.getSelectedRow() >= 0 && attrList.getRowCount() > attrList.getSelectedRow();
		} else {
			return recList.getSelectedIndex() >= 0 && recListModel.size() > recList.getSelectedIndex();
		}
	}
	
	/**
	 * Get the selected attribute
	 * @return
	 * 		The attribute currently selected
	 */
	private String getSelectedAttr() {
		return (String) attrList.getValueAt(attrList.getSelectedRow(), 0);
	}

}
