/*******************************************************************************
* This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
* Software Process Configurator MQP
* Advised by Professor Gary Pollice
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*    Jake Todaro
*    Pragathi Balasubramanian
*******************************************************************************/
package app;

import java.io.IOException;
import java.net.URISyntaxException;

import javax.swing.UnsupportedLookAndFeelException;
import xmlParser.DialogParser;
import database.Database;
import database.Db4oDatabase;
import dialogView.DialogView;
import dialogView.StartPage;

/** This class holds the main method.
* 
 * @author Jake Todaro
* @author Pragathi Balasubramanian
*
*@version 04/04/12
*/

public class SPC {
                
	static StartPage sp_view;
	
	/**
	* the main method for the Software Process Configurator
	* 
	 * @param args
	*            - default main method arguments
	* @throws UnsupportedLookAndFeelException 
	 * @throws IllegalAccessException 
	 * @throws InstantiationException 
	 * @throws ClassNotFoundException 
	 * @throws URISyntaxException 
	 * @throws IOException 
	 */
	public static void main(String[] args) throws ClassNotFoundException, InstantiationException, IllegalAccessException, UnsupportedLookAndFeelException, URISyntaxException, IOException {
		//PCIDB.initialize();
		sp_view = new StartPage();
		sp_view.setVisible(true);
	}
	
	/**
	* Sets the asset database for a particular dialog
	* @param dbname - name of asset database used for a dialog
	*/
	public static Database setDB(String dbname){
        Db4oDatabase database = new Db4oDatabase();
        database.use("db/"+ dbname);
        return database;
	}
	
	/**
	* Sets the dialog chosen by the user
	* 
	* @param dialogName - name of dialog that the user will be running through
	 * @throws UnsupportedLookAndFeelException 
	 * @throws IllegalAccessException 
	 * @throws InstantiationException 
	 * @throws ClassNotFoundException 
	*/
	public static void setDialog(String dialogName) {
        DialogParser.parseDialog("xmlDialogs/" + dialogName,SPC.setDB("SpcDB"));
	}
	
	/**
	* Closes the start page once the user selects the dialog 
	 * Starts the dialog page
	*/
	public static void startDialog() throws ClassNotFoundException, InstantiationException, IllegalAccessException, UnsupportedLookAndFeelException{
        sp_view.setVisible(false);
        sp_view.dispose();
        DialogView view = new DialogView();
		view.setVisible(true);
	}
}
