/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package attribute;

import value.Value;

/**
 * This class represents an Attribute of a Project.
 * It contains a name that represents it, and a Value
 * that represents the information inside.
 * 
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public class Attribute{
	
	private String name;
	private Value value;
	
	/**
	 * Attribute Constructor.
	 * @param name String containing name 
	 * @param value Value class of information
	 */
	public Attribute(String name, Value value)
	{
		this.name = name;
		this.value = value;
	}

	/**
	 * Gets the name of the attribute
	 * @return String containing attribute name
	 */
	public String getName() {
		return name;
	}
	
	/**
	 * Gets the Value of the attribute
	 * @return Value containing attribute information
	 */
	public Value getValue() {
		return value;
	}
	
	public boolean equals(Object o) {
		if(!(o instanceof Attribute)) {
			return false;
		}
		Attribute other = (Attribute)o;
		return name.equals(other.getName()) && value.equals(other.getValue());
	}

}
