/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package attribute;

import value.Value;
import value.valueData.ValueType;

/**
 * Describes the contents of an attribute.
 * These are mapped to attributes for user reference.
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public class AttributeDescription {
	
	private final String name;
	private final ValueType type;
	private final String description;
	
	/**
	 * Constructor for an AttributeDescription.
	 * @param name Name of the Attribute being described
	 * @param type A ValueType representing the type of Value of the Attribute
	 * @param description String containing user information
	 */
	public AttributeDescription(String name, ValueType type, String description) {
		this.name = name;
		this.type = type;
		this.description = description;
	}
	
	/**
	 * Constructor for an AttributeDescription with no description yet.
	 * @param name Name of the Attribute being described
	 * @param type A ValueType representing the type of Value of the Attribute
	 */
	public AttributeDescription(String name, ValueType type)
	{
		this(name,type,"");
	}
	/**
	 * Gets the name of the AttributeDescription
	 * @return String containing the name
	 */
	public String getName() {
		return name;
	}
	
	/**
	 * Gets the ValueType that corresponds to the attribute being described
	 * @return A ValueType to identify the type of Value
	 */
	public ValueType getType() {
		return type;
	}
	
	/**
	 * Gets the description of the attribute that this object corresponds to
	 * @return A String containing a description
	 */
	public String getDescription() {
		return description;
	}
	
	/**
	 * Constructs an Attribute using the name of this AttributeDescription
	 * @param value the Value for creating the Attribute
	 * @return the newly created Attribute
	 */
	public Attribute makeAttribute(Value value) {
		return new Attribute(name,value);
	}

}
