/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package booleanExpression;

import java.util.LinkedList;
import java.util.List;

/** this abstract class represents a boolean Expression.
 * BooleanExpressions are either and, or, or not. Triggers from
 * the XML dialogs are parsed and translated into BooleanExpressions
 * to be evaluated while running the Dialog. a BooleanExpression is
 * a BooleanValue, so a BooleanExpression may contain other BooleanExpressions.
 * 
 * @author jake todaro
 * @version 12/23/11
 */

public abstract class BooleanExpression implements BooleanValue{
	
	protected List<BooleanValue> atoms;
	
	/** constructor initializes the fields
	 */
	protected BooleanExpression(){
		atoms = new LinkedList<BooleanValue>();
	}

	/** add a BooleanValue to this BooleanExpression
	 * 
	 * @param atom - the BooleanValue to add
	 */
	public void addAtom(BooleanValue atom){
		atoms.add(atom);
	}
	
	/** return this BooleanExpressions list of BooleanValues
	 * 
	 * @return this BooleanExpressions list of BooleanValues
	 */
	public List<BooleanValue> getAtomList(){
		return atoms;
	}
}
