/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package booleanExpression;

import java.util.List;

import dialog.Answer;

/** this class represents a not expression that the dialog
 * writer can use to define more complex triggers.
 * 
 * @author jake todaro
 * @version 12/23/11
 */

public class NotExpression implements BooleanValue{

	private final BooleanValue atom;
	/** constructor initializes the fields
	 * 
	 * @param atom the BooleanValue for this NotExpression
	 */
	public NotExpression(BooleanValue atom){
		this.atom = atom;
	}
	
	/** return the BooleanValue of this NotExpression
	 * @return
	 */
	public BooleanValue getAtom(){
		return atom;
	}
	
	@Override
	public boolean value() {
		if(atom instanceof Answer){
			//the question must be asked and not have been answered a certain way
			//it is not sufficient enough to say return true if this answer is not in the answer set
			
			final List<Answer> parentAnswers = ((Answer)atom).getParentQuestion().getAnswerList();
			final int answerNum = ((Answer) atom).getAnswerNum();
			
			//if any of these are in the answer set, the question was answered appropriately
			for(int i = 0; i < parentAnswers.size(); i++){
				if(parentAnswers.get(i).getAnswerNum() != answerNum){
					if(parentAnswers.get(i).value()){
						return true;
					}
				}
			}
			
			return false;
		}
		else{
			return !atom.value();
		}
	}
	
	@Override
	public boolean equals(Object input){
		if(this == input){
			return true;
		}
		
		return input instanceof NotExpression &&
			atom.equals(((NotExpression) input).getAtom());
	}
}
