/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package database;

import java.util.Collection;

import recommendation.Recommendation;
import attribute.AttributeReference;

/**
 * Represents a Database (e.g. a DB4O database).
 * @author Wesley Ripley, Adam Talbot
 * @version 11/24/12
 */
public interface Database {
	
	/**
	 * Prepares the specified database for usage.
	 * @param dbName - the name of the database file
	 */
	public void use(String dbName);
	
	/**
	 * Stores an object in the database.
	 * @param o The object to be stored
	 * @return true if no exceptions were thrown
	 */
	public boolean store(Object o);
	
	/**
	 * Deletes an object from the database.
	 * @param o The object to be deleted
	 * @return true if no exceptions were thrown
	 */
	public boolean delete(Object o);
	
	/**
	 * Closes the current database (run this when queries are
	 * completed)
	 */
	public void close();
	
	/**
	 * Queries the Database for all Recommendations.
	 * @return a Collection of Recommendations
	 */
	public Collection<Recommendation> getAllRecommendations();
	
	/**
	 * Queries the Database for an AttributeReference.
	 * @return a single AttributeReference
	 */
	public AttributeReference getAttributeReference();
	
	/**
	 * Retrieves a specific Recommendation by name
	 */
	public Recommendation getRecommendation(String name);

	

}
