/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Jake Todaro, Pragathi Balasubramanian
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro, Wesley Ripley, Adam Talbot
 *******************************************************************************/

package database;

import java.util.Collection;

import recommendation.Recommendation;
import attribute.AttributeReference;
import com.db4o.Db4oEmbedded;
import com.db4o.ObjectContainer;
import com.db4o.ObjectSet;
import com.db4o.config.CommonConfiguration;
import com.db4o.config.EmbeddedConfiguration;
import com.db4o.query.Predicate;

/**
 * This class represents a database of Recommendations.
 * This class provides the rest of the code with access to
 * the ObjectContainer of the Database. The use method sets
 * dboc to the ObjectContainer for the database with the
 * specified name.
 * 
 * @author Jake Todaro, Adam Talbot
 * @version 11/24/12
 */
public class Db4oDatabase implements Database{
	
	private ObjectContainer dboc;
	
	
	public Db4oDatabase() {
		dboc = null;
	}

	@Override
	public void use(String dbName)
	{
		final EmbeddedConfiguration config = Db4oEmbedded.newConfiguration();
		final CommonConfiguration commonConfig = config.common();
		commonConfig.activationDepth(10);
		commonConfig.updateDepth(10);
		commonConfig.objectClass(AttributeReference.class).cascadeOnActivate(true);
		commonConfig.objectClass(AttributeReference.class).cascadeOnUpdate(true);
		commonConfig.objectClass(AttributeReference.class).cascadeOnDelete(true);
		dboc = Db4oEmbedded.openFile(config, dbName);
	}
	
	@Override
	public void close() {
		if(dboc != null) {
			dboc.close();
		}
	}
	
	@Override
	public boolean store(Object o) {
		try{
			dboc.store(o);
		}catch(Exception e){
			return false;
		}
		return true;
	}
	
	@Override
	public boolean delete(Object o) {
		try{
			dboc.delete(o);
		}catch(Exception e){
			return false;
		}
		return true;
	}
	
	@Override
	public Collection<Recommendation> getAllRecommendations() {
		return dboc.query(Recommendation.class);
	}

	@Override
	public AttributeReference getAttributeReference() {
		ObjectSet<AttributeReference> results = dboc.query(AttributeReference.class);
		if(results.hasNext()) {
			return results.next();
		} else {
			return null;
		}
	}

	@SuppressWarnings("serial")
	@Override
	public Recommendation getRecommendation(final String name) {
		if(name == null) {
			return null;
		}
		ObjectSet<Recommendation> results = dboc.query(new Predicate<Recommendation> () {
			public boolean match(Recommendation rec) {
				return name.equals(rec.getName());
			}
		});
		if(results.hasNext()) {
			return results.next();
		} else {
			return null;
		}
	}
	
}
