/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package database;

import java.util.ArrayList;
import java.util.Collection;

import recommendation.Recommendation;
import attribute.AttributeReference;

/**
 * An implementation of Database that doesn't actually do much at all.
 * It is only for certain testing purposes.
 * TODO: Delete when confirmed to be unnecessary.
 * @author Wesley Ripley, Adam Talbot
 * @version 12/4/12
 */
public class TestDatabase implements Database{

	private Collection<Recommendation> recs;
	private AttributeReference attrRef;
	
	public TestDatabase(Collection<Recommendation> recs, AttributeReference attrRef) {
		this.recs = recs;
		this.attrRef = attrRef;
	}
	
	public TestDatabase() {
		this(new ArrayList<Recommendation>(),new AttributeReference());
	}
	@Override
	public void use(String dbName) {
		//no actual database so do nothing on purpose
		return;
	}

	@Override
	public void close() {
		//no actual database so do nothing on purpose
		return;
	}

	@Override
	public Collection<Recommendation> getAllRecommendations() {
		return recs;
	}

	@Override
	public AttributeReference getAttributeReference() {
		return attrRef;
	}

	@Override
	public boolean store(Object o) {
		// no actual database so return false to signal failure
		return false;
	}

	@Override
	public boolean delete(Object o) {
		// no actual database so return false to signal failure
		return false;
	}

	@Override
	public Recommendation getRecommendation(String name) {
		if(name == null) {
			return null;
		}
		for(Recommendation rec : recs) {
			if(name.equals(rec.getName())) {
				return rec;
			}
		}
		return null;
	}

}
