/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

/**
 * This is the dialog controller class. This class handles administering a dialog
 * and getting the selected answers from the user. This class also handles selecting
 * which questions to ask.
 * 
 * @author jake todaro
 * 
 * @version 12/09/11
 */
public class ConsoleController {

	/** run the specified Dialog
	 * 
	 * @throws IOException if something goes wrong with the input reader
	 */
	public static void runDialog() throws IOException{
		for(int i = 0; i < Dialog.getSubDialogList().size(); i++){
			runSubDialog(Dialog.getSubDialogList().get(i));
		}
	}
	
	/**
	 * run the SubDialog
	 * 
	 * @param subDialog - the subDialog to run
	 * @throws IOException if something goes wrong with the input reader
	 */
	public static void runSubDialog(SubDialog subDialog) throws IOException {
		for (int i = 0; i < subDialog.getQuestionList().size(); i++) {
			
			Question question = subDialog.getQuestionList().get(i);
			
			if(question.getTrigger().value()){
				displayQuestion(question);
				readAnswerFromUser(question);
			}
		}
	}
	
	/**
	 * display the question through the console
	 * 
	 * @param question - the question to be displayed
	 */
	private static void displayQuestion(Question question) {
		
		System.out.println("Question " + question.getId() + ": " + question.getQuestionStatement());
		for (int i = 0; i < question.getAnswerList().size(); i++){
			System.out.println(i + " "
					+ question.getAnswerList().get(i).getAnswerText());
		}
		System.out.println("Type the index of your answer followed by enter");
	}

	/**
	 * get the answer from the user
	 * 
	 * @param question - the question that the user is answering
	 * @throws IOException if something does wrong with the input reader
	 */
	private static void readAnswerFromUser(Question question) throws IOException {
		String input = "";
		final BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
		input = br.readLine();

		final Answer answer = question.getAnswerList().get(Integer.parseInt(input));
		
		answer.select();
	}
}
