/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;
import java.util.PriorityQueue;

import recommendation.Constraints;
import recommendation.Recommendation;
import recommendation.RecommendationResult;
import attribute.Attribute;
import attribute.AttributeReference;
import database.Database;

/** this class represents a Dialog. a Dialog consists of a series of SubDialogs.
 *
 * @author Jake Todaro
 * 
 * @version 12/09/11
 */

public class Dialog {

	private static List<SubDialog> subDialogList = null;
	private static Constraints constraints = null;
	private static Database database = null;
	private static AttributeReference attrRef = null;
	
	private static Question currentQuestion = null;
	
	/** constructor initializes the fields
	 */
	private Dialog(Database database){
		subDialogList = new LinkedList<SubDialog>();
		constraints = new Constraints();
		Dialog.database = database;
		attrRef = null;
	}
	
	public static void startDialog(Database database){
		new Dialog(database);
	}
	
	/** add a SubDialog to the Dialog
	 * 
	 * @param subDialog - the SubDialog object to add to the dialog
	 */
	public static void addSubDialog(SubDialog subDialog){
		subDialogList.add(subDialog);
	}
	
	public static List<SubDialog> getSubDialogList(){
		return subDialogList;
	}

	
	/** return the SubDialog that has the specified title
	 * 
	 * @param title - the title of the SubDialog to return
	 * @return - the SubDialog with the specified title
	 */
	public static SubDialog findSubDialogByTitle(String title){
		for(int i = 0; i < subDialogList.size(); i++){
			if(subDialogList.get(i).getTitle().equals(title)){
				return subDialogList.get(i);
			}
		}
		
		return null;
	}
	
	public static void addAttribute(Attribute attr) {
		constraints.addAttribute(attr);
	}
	
	public static void removeAttribute(Attribute attr) {
		constraints.removeAttribute(attr.getName());
	}
	
	public static Attribute getAttribute(String name) {
		return constraints.getAttribute(name);
	}
	
	/** get the next Question to be asked
	 * 
	 * @return the nextQuestion to be asked
	 */
	public static Question getNextQuestion(){
                
		//if first time running
	    if(currentQuestion == null){
	    	currentQuestion = subDialogList.get(0).getQuestionList().get(0);
	    }
        else{
        	
        	SubDialog parent = currentQuestion.getParentSubDialog();
        	int parentIndex = Dialog.getSubDialogList().indexOf(parent);
        	final int questionIndex = parent.getQuestionList().indexOf(currentQuestion);
	                        
	        //if current question is last question in the subDialog
	        if(questionIndex == parent.getQuestionList().size() - 1){
	        	//if this is the last subDialog
                if(parentIndex == Dialog.getSubDialogList().size() - 1){
                	currentQuestion = null;
                }
	            else{
	            	//check if subdialog trigger is true
	            	if(subDialogList.get(parentIndex + 1).getTrigger().value()){
	            		currentQuestion = subDialogList.get(parentIndex + 1).getQuestionList().get(0);
	            	}
	            	//if its not true, set the current question to the last question of this subdialog and call nextQuestion
	            	else{
	            		parent = subDialogList.get(parentIndex + 1);
	            		parentIndex = Dialog.getSubDialogList().indexOf(parent);
	            		
	            		currentQuestion = parent.getQuestionList().get(parent.getQuestionList().size() - 1);
	            		getNextQuestion();	            		
	            	}
	            }
	        }
	        //there is a next question in this subDialog
	        else{
	        	currentQuestion = parent.getQuestionList().get(questionIndex + 1);
	        }
        }

	    if(currentQuestion == null){
	    	return null;
	    }
	    else if(currentQuestion.getTrigger().value()){
	    	return currentQuestion;
	    }
	    else{
	    	return getNextQuestion();
	    }
	}
	
	public static void close() {
		if(database != null){
			database.close();
		}
	}
	
	public static AttributeReference getAttributeReference() {
		if(attrRef == null) {
			attrRef = database.getAttributeReference();
			if(attrRef == null) {
				attrRef = new AttributeReference();
			}
		}
		return attrRef;
	}
	
	public static PriorityQueue<RecommendationResult> getResultingRecommendations() {
		Collection<Recommendation> recommendations = database.getAllRecommendations();
		PriorityQueue<RecommendationResult> rankedRecs = new PriorityQueue<RecommendationResult>(recommendations.size());
		for(Recommendation rec : recommendations) {
			RecommendationResult result = rec.evaluateScenario(constraints);
			if(result.isRequired() || result.getConfidence() > 0) {
				rankedRecs.add(result);
			}
			
		}
		return rankedRecs;
	}

}
