/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package dialog;

import java.util.LinkedList;
import java.util.List;

import booleanExpression.BooleanValue;
import booleanExpression.TrueBooleanAtom;

/**
 * The Dialog class holds all of the questions that belong to a dialog.
 * It is basically a wrapper class for a List
 * 
 * @author Jake Todaro
 * 
 * @version 12/09/11
 */

public class SubDialog{
	
	private final String title;
	private final List<Question> questionList;
	private BooleanValue trigger;
	
	/**
	 * constructor initializes fields
	 * 
	 * @param title - the title of this SubDialog
	 */
	public SubDialog(String title){
		this.title = title;
		questionList = new LinkedList<Question>();
		trigger = new TrueBooleanAtom();
	}
	
	/** add the given question to list of questions
	 * 
	 * @param question the question to add
	 */
	public void addQuestion(Question question){
		question.setParentSubDialog(this);
		questionList.add(question);
	}
	
	/** return the title of this SubDialog
	 * 
	 * @return the title of this SubDialog
	 */
	public String getTitle(){
		return title;
	}

	public List<Question> getQuestionList() {
		return questionList;
	}
	
	/** get the Question with the given id
	 * 
	 * @param id - the id to check for
	 * @return the Question with the given id
	 */
	public Question getQuestionById(String id){
		for(Question question: questionList){
			if(question.getId().equals(id)){
				return question;
			}
		}
		
		return null;
	}
	
	public BooleanValue getTrigger(){
		return trigger;
	}
	
	public void setTrigger(BooleanValue trigger){
		this.trigger = trigger;
	}
	
	@Override
	public boolean equals(Object input){
		if(this == input){
			return true;
		}
				
		return input instanceof SubDialog && 
			title.equals(((SubDialog) input).getTitle()) &&
			questionList.equals(((SubDialog) input).getQuestionList());
	}

	@Override
	public String toString(){
		String result = title + "\n";
		for(int i = 1; i <= questionList.size(); i++){
			result += "\n\t" + questionList.get(i).toString();
		}
		
		return result;
	}
}
