/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Pragathi Balasubramanian
 *    Jake Todaro
 *******************************************************************************/
package dialogView;


import java.awt.Color;
import java.awt.Desktop;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GraphicsConfiguration;
import java.awt.Rectangle;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.io.IOException;
import java.util.PriorityQueue;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;

import net.miginfocom.swing.MigLayout;
import recommendation.RecommendationResult;
import recommendationView.TemplateParser;
import dialog.Dialog;
import dialog.Question;
import dialogView.controller.Controller;
import dialogView.controller.NextButtonListener;

/** this is the view class for the window that displays questions
 * 
 * @author pragathi balasubramanian
 * @author jake todaro
 * @version 03/29/12
 */
public class DialogView extends JDialog {


	private static final long serialVersionUID = 1L;
	JPanel questionPanel = new JPanel();	
	static JTextArea question = new JTextArea("");	
	static JPanel radioButtonsPanel = new JPanel();
	static JPanel buttonPanel = new JPanel();
	public static ButtonGroup answers = null;
	static JButton nextButton;
	static JScrollPane radioScroll;


	/**
	 * Create the GUI for the user "interview".
	 * @throws UnsupportedLookAndFeelException 
	 * @throws IllegalAccessException 
	 * @throws InstantiationException 
	 * @throws ClassNotFoundException 
	 */
	public DialogView() throws ClassNotFoundException, InstantiationException, IllegalAccessException, UnsupportedLookAndFeelException {

		try{
			UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
		}catch(UnsupportedLookAndFeelException e) {}

		final JDialog f = this;

		// Setting window location
		GraphicsConfiguration gc = f.getGraphicsConfiguration();   
		Rectangle bounds = gc.getBounds(); 

		// Setting background color and font of main content panel
		getContentPane().setBackground(new Color(240, 255, 255));

		//Miglayout specs for window
		setBounds((int) ((bounds.width/2) -250), (int) ((bounds.height/2) - 250), 509, 500);
		getContentPane().setLayout(new MigLayout("wrap 1", "[490px,grow]", "[75px,grow][10px,grow][250px][50px]"));

		//Adding the SPC logo

		JLabel imageLabel = new JLabel();
		imageLabel.setBackground(Color.BLACK);
		imageLabel.setBorder(null);
		imageLabel.setLayout(new MigLayout("", "[490px]", "[74px]"));
		imageLabel.setIcon(new javax.swing.ImageIcon(this.getClass().getResource("/imgs/SPC Logo.png")));
		getContentPane().add(imageLabel, "cell 0 0");

		FlowLayout flowLayout = (FlowLayout) questionPanel.getLayout();
		flowLayout.setAlignment(FlowLayout.LEFT);
		questionPanel.setBackground(new Color(240, 255, 255));
		getContentPane().add(questionPanel, "cell 0 1,growx,aligny top");
		question.setEditable(false);
		question.setSize(470, 100);
		question.setFont(new Font("Constantia", Font.PLAIN, 18));
		question.setForeground(new Color(0, 0, 0));
		question.setBackground(new Color(240, 255, 255));
		question.setLineWrap(true);
		question.setWrapStyleWord(true);
		questionPanel.add(question);

		radioButtonsPanel.setBackground(new Color(240, 255, 255));
		radioButtonsPanel.setLayout(new MigLayout("", "[490px]", "[10px]"));
		radioScroll = new JScrollPane(radioButtonsPanel);
		radioScroll.setBorder(null);
		radioScroll.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
		radioScroll.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED);
		
		getContentPane().add(radioScroll, "cell 0 2,aligny top");
		
		buttonPanel.setBackground(new Color(240, 255, 255));


		buttonPanel.setLayout(new FlowLayout(FlowLayout.RIGHT));
		getContentPane().add(buttonPanel, "cell 0 3,growx,aligny top");		
		nextButton = new JButton("Next");
		nextButton.setBackground(new Color(176, 224, 230));

		nextButton.addActionListener(new NextButtonListener());

		buttonPanel.add(nextButton);





		this.addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(WindowEvent arg0) {
				Dialog.close();
				f.dispose();
			}
		});

		renderQuestionView();				

	}


	/** renders the page corresponding to the question and its answers
	 * 
	 */
	public static void renderQuestionView(){
		answers = new ButtonGroup();
		final Question q = Controller.getCurrentQuestion();
		if(q == null){
			renderDone();
		}
		else{
			clearRadios();
			question.setText(q.getQuestionStatement());
			for(int i = 0; i < q.getAnswerList().size(); i++){
				JRadioButton rb = new JRadioButton(q.getAnswerList().get(i).getAnswerText());
				rb.setBackground(new Color(240, 255, 255));
				rb.setFont(new Font("Constantia", Font.PLAIN, 16));
				answers.add(rb);
				radioButtonsPanel.add(rb, "wrap");
			}
			radioScroll.setSize(490, 250);
		}

	}

	/** remove all of the radios from the panel and delete them from the list */
	private static void clearRadios(){

		radioButtonsPanel.removeAll();
		radioButtonsPanel.updateUI();
		radioButtonsPanel.validate();
		


	}

	/**  Render the final screen for thanks and results */
	private static void renderDone(){
		question.setText("Thank you for using the SPC. Here are your results: ");
		clearRadios();
		
		PriorityQueue<RecommendationResult> rankedRecs = Dialog.getResultingRecommendations();
		TemplateParser templateParser = new TemplateParser();
		File output = templateParser.parseTemplate(rankedRecs);
		if (output == null){
			JLabel errorMessage = new JLabel("Unable to generate results.");
			radioButtonsPanel.add(errorMessage);
		}
		else{
			JLabel resultPath = new JLabel(output.getAbsolutePath());
			resultPath.setFont(new Font("Constantia", Font.PLAIN, 16));
			radioButtonsPanel.add(resultPath);
			try {
				Desktop.getDesktop().open(output);
			} catch (IOException e) {
				e.printStackTrace();
			}
		}

		nextButton.setVisible(false);
	}

}
