/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Pragathi Balasubramanian
 *******************************************************************************/

package dialogView;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GraphicsConfiguration;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.IOException;
import java.net.URISyntaxException;
import java.util.List;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;

import net.miginfocom.swing.MigLayout;
import dialog.Dialog;
import dialogView.controller.StartPageController;

/** This class represents the start page for the SPC
* 
* @author Pragathi Balasubramanian
*
*@version 04/04/12
*/
@SuppressWarnings("serial")
public class StartPage extends JFrame {

	private static JComboBox comboBox = new JComboBox();
	
	/**
	 * Create the Starting Page for the SPC
	 * 
	 * @throws UnsupportedLookAndFeelException 
	 * @throws IllegalAccessException 
	 * @throws InstantiationException 
	 * @throws ClassNotFoundException 
	 * @throws URISyntaxException 
	 * @throws IOException 
	 */
	public StartPage() throws ClassNotFoundException, InstantiationException, IllegalAccessException, UnsupportedLookAndFeelException, URISyntaxException, IOException {
		
		final JFrame f = this;
		
		try{
			UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
		}catch(UnsupportedLookAndFeelException e) {}
		
		// Setting window location
		GraphicsConfiguration gc = f.getGraphicsConfiguration();   
		Rectangle bounds = gc.getBounds(); 

		// Setting background color and font of main content panel
		getContentPane().setBackground(new Color(240, 255, 255));
		
		//Miglayout specs for window
		setBounds((int) ((bounds.width/2) -250), (int) ((bounds.height/2) - 250), 509, 500);
		getContentPane().setLayout(new MigLayout("", "[490px,grow]", "[74px][100px][50px][200px][50px]"));
		
		//Adding the SPC logo		
		JLabel imageLabel = new JLabel();
		imageLabel.setBackground(Color.BLACK);
		imageLabel.setBorder(null);
		imageLabel.setLayout(new MigLayout("", "[490px]", "[74px]"));
		imageLabel.setIcon(new javax.swing.ImageIcon(this.getClass().getResource("/imgs/SPC Logo.png")));
		getContentPane().add(imageLabel, "cell 0 0,alignx left,aligny top");
		
		//Welcome text for the start page
		JPanel welcomePanel = new JPanel();
		JLabel welcome = new JLabel();
		FlowLayout flowLayout = (FlowLayout) welcomePanel.getLayout();
		flowLayout.setAlignment(FlowLayout.LEFT);
		welcomePanel.setBackground(new Color(240, 255, 255));
		welcome.setFont(new Font("Constantia", Font.PLAIN, 18));
		welcome.setForeground(new Color(0, 0, 0));
		welcome.setText("Welcome to the SPC. Please choose your dialog:");
		welcomePanel.add(welcome);
		getContentPane().add(welcomePanel, "cell 0 1 ");		
		getContentPane().add(comboBox, "cell 0 3,growx");
		setComboBox();
		
		//The start button must set the dialog being used
		JButton btnStart = new JButton("Start");
		btnStart.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				try {
					StartPageController.setDialog( (String) comboBox.getSelectedItem());
				} catch (ClassNotFoundException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (InstantiationException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (IllegalAccessException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (UnsupportedLookAndFeelException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		});
		
		getContentPane().add(btnStart, "cell 0 4, alignx right");
		
		
		this.addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(WindowEvent arg0) {
					Dialog.close();
				f.dispose();
			}
		});
	}

	/**
	 * Puts the names of the available dialogs into the combo box
	 * @throws URISyntaxException 
	 * @throws IOException 
	 */
	private static void setComboBox() throws URISyntaxException, IOException{
		List<String> dialogNames= StartPageController.getDialogs();
		
		for(int i = 0; i < dialogNames.size(); i ++){
			comboBox.addItem(dialogNames.get(i));
		}
	}
}
