/*******************************************************************************
* This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
* Software Process Configurator MQP
* Advised by Professor Gary Pollice
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*    Jake Todaro
*    Pragathi Balasubramanian
*******************************************************************************/
package dialogView.controller;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.swing.UnsupportedLookAndFeelException;

import app.SPC;

/** 
* This class is the controller for the start page - it gets the different available dialogs 
* and sets the dialog that the user will be working with. 
* 
* @author Pragathi Balasubramanian
*
*@version 04/04/12
*/
public class StartPageController {

	/**
	 * Gets all the dialog names that are currently in the app package
	 * @return list of dialog names available currently
	 */
	public static List<String> getDialogs(){
		List<String> dialogNames = new ArrayList<String>();
	    File folder = new File("xmlDialogs");
	    File[] listOfFiles = folder.listFiles();

	    for(int i = 0 ; i < listOfFiles.length; i++){
	    	if(listOfFiles[i].getName().startsWith("[DIALOG]")){
	    		dialogNames.add(listOfFiles[i].getName());
	    	}	    	
	    }
	    
	    
	    return dialogNames;
	}
	
	/**
	 * Sets the dialog on the main method to the one that the user has selected
	 * 
	 * @param dialogName - dialog that the user has chosen to go through
	 * @throws ClassNotFoundException
	 * @throws InstantiationException
	 * @throws IllegalAccessException
	 * @throws UnsupportedLookAndFeelException
	 */
	public static void setDialog(String dialogName) throws ClassNotFoundException, InstantiationException, IllegalAccessException, UnsupportedLookAndFeelException{
		SPC.setDialog(dialogName);
		SPC.startDialog();
	}
}
