/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package dsl;

import java.io.IOException;
import java.io.Reader;

import org.antlr.runtime.ANTLRReaderStream;
import org.antlr.runtime.CommonTokenStream;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.tree.CommonTreeNodeStream;

import recommendation.Recommendation;
import recommendation.RecommendationBuilder;
import database.Database;
import dsl.antlr.DSLLexer;
import dsl.antlr.DSLParser;
import dsl.antlr.DSLRecCreator;

/**
 * Used to load Recommendations using the Domain Specific Language 
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public class DSLLoader {
	
	/**
	 * Loads in a Recommendation
	 * @param reader Reader for a character stream
	 * @param database The Database to use
	 * @return the completed Recommendation
	 * @throws IOException
	 * @throws RecognitionException
	 */
	public static Recommendation loadRecommendation(Reader reader, Database database) throws IOException, RecognitionException {
		DSLParser p;
		p = new DSLParser(
				new CommonTokenStream(
						new DSLLexer(
								new ANTLRReaderStream(
										reader))));
		p.setTreeAdaptor(new SpcASTAdaptor());
		SpcAST tree = (SpcAST)p.recommendation().getTree();
		DSLRecCreator recCreator = new DSLRecCreator(new CommonTreeNodeStream(new SpcASTAdaptor(),tree));
		recCreator.setTreeAdaptor(new SpcASTAdaptor());
		tree = (SpcAST) recCreator.recommendation().getTree();
		RecommendationBuilder recBuilder = recCreator.getRecBuilder();
		Recommendation rec = recBuilder.buildRecommendation();
		
		Recommendation previousRec = database.getRecommendation(rec.getName());
		if(previousRec != null) {
			database.delete(previousRec);
		}
		database.store(rec);
		return rec;
	}

}
