/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation;

import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import attribute.Attribute;

/**
 * Represents the collection of attributes that the user has provided,
 * and that the Recommendations will check from when determining what
 * Recommendations are valid for the user's query.
 * @author Wesley Ripley, Adam Talbot
 * @version 10/03/12
 */
public class Constraints implements Iterable<Attribute> {

	private Map<String,Attribute> attrMap;
	
	/**
	 * Constructor with no attributes added
	 */
	public Constraints() {
		attrMap = new HashMap<String,Attribute>();
	}
	
	/**
	 * Constructor that appends a collection of attributes to create
	 * a full collection of constraints
	 * @param attrs
	 */
	public Constraints(Collection<Attribute> attrs) {
		this();
		for(Attribute attr : attrs) {
			addAttribute(attr);
		}
	}
	
	/**
	 * Adds an attribute to the list of constraints
	 * @param attr The Attribute to be added
	 */
	public void addAttribute(Attribute attr) {
		attrMap.put(attr.getName(), attr);
	}
	
	/**
	 * Gets an Attribute that is currently in the list
	 * @param name The name of the Attribute
	 * @return The Attribute in the list if it exists, or null
	 */
	public Attribute getAttribute(String name) {
		return attrMap.get(name);
	}
	
	/**
	 * Removes an Attribute from the list
	 * @param name The name of the Attribute
	 * @return The Attribute that was removed, or null if
	 * it could not find it
	 */
	public Attribute removeAttribute(String name) {
		return attrMap.remove(name);
	}

	@Override
	public Iterator<Attribute> iterator() {
		return attrMap.values().iterator();
	}
	
	@Override
	public boolean equals(Object o) {
		if(o == null) {
			return false;
		}
		Constraints other = (Constraints)o;
		return attrMap.equals(other.attrMap);
	}
	
	
}
