/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation;

import java.util.List;

import recommendation.asset.Asset;

/**
 * A Recommendation is a set of information that describes
 * a recommended practice.  This typically includes a name,
 * description, summary, and collections of both Scenarios and
 * Assets.
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public interface Recommendation{
	
	/**
	 * Given a scenario, compare it to its own scenarios
	 * to assign an evaluation to this Recommendation.
	 * @param scenario
	 * @return currently an int.
	 */
	RecommendationResult evaluateScenario(Constraints scenario);
	
	/**
	 * Gets this Recommendation's description, which should be
	 * long compared to the summary
	 * @return a String for the description
	 */
	String getDescription();
	
	/**
	 * Gets a short summary of this Recommendation
	 * @return a String for the summary
	 */
	String getSummary();

	/**
	 * Gets the name of this Recommendation
	 * @return a String for the name
	 */
	String getName();
	
	/**
	 * Gets a list of Assets that are relevant to this
	 * Recommendation.  This only gets Assets that are ALWAYS
	 * relevant, and not Scenario-specific Assets.
	 * @return a List of Assets.
	 */
	List<Asset> getAssetList();

	/**
	 * Gets a list of all Categories that this Recommendation is
	 * a part of.
	 * @return a List of Category Strings.
	 */
	List<String> getCategories();
	
	

}
