/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation;

import java.util.ArrayList;
import java.util.List;

import recommendation.asset.Asset;

/**
 * Class used to build Recommendations.  Specifically builds
 * BasicRecommendations in this implementation.
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public class RecommendationBuilder {
	private String name;
	private String summary;
	private String description;
	private List<Scenario> scenarios;
	private List<Asset> assets;
	private List<String> categories;
	
	public RecommendationBuilder() {
		name = null;
		summary = "";
		description = null;
		scenarios = new ArrayList<Scenario>();
		assets = new ArrayList<Asset>();
		categories = new ArrayList<String>();
	}
	
	public void addScenario(Scenario scenario) {
		scenarios.add(scenario);
	}
	
	public List<Scenario> getScenarios() {
		return scenarios;
	}
	
	public String getName() {
		return name;
	}


	public void setName(String name) {
		this.name = name;
	}


	public String getSummary() {
		return summary;
	}


	public void setSummary(String summary) {
		this.summary = summary;
	}


	public String getDescription() {
		return description;
	}


	public void setDescription(String description) {
		this.description = description;
	}
	
	public void addAsset(Asset asset) {
		assets.add(asset);
	}
	
	public List<Asset> getAssets() {
		return assets;
	}
	
	public List<String> getCategories() {
		return categories;
	}
	
	public void addCategory(String category) {
		categories.add(category);
	}

	/**
	 * Builds a BasicRecommendation based on the information contained
	 * within this RecommendationBuilder.
	 * @return a Recommendation in the form of a BasicRecommendation.
	 */
	public Recommendation buildRecommendation() {
		if(scenarios.isEmpty() || name == null || description == null){
			throw new IllegalStateException("Canno't build recommendation without a name, description, and at least one scenario");
		}
		return new BasicRecommendation(name,scenarios,assets,description,summary,categories);
	}
}
