/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import recommendation.asset.Asset;
import recommendationView.Templateable;

/**
 * After analyzing a Recommendation based on its Scenarios, a
 * RecommendationResult is created that contains the results of
 * the analysis.  This is that class.
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public class RecommendationResult implements Templateable, Comparable<RecommendationResult>{
	
	private int confidence;
	private String explanation;
	private List<Asset> assets;
	private boolean required;
	private Recommendation origRec;
	
	/**
	 * Constructor for a RecommendationResult
	 * @param confidence a numerical value indicating how confidently
	 * the Recommendation should be given
	 * @param explaination an explanation as to why the Recommendation
	 * is being given 
	 * @param assets a List of all Assets to provide
	 * @param required true if this is a required Recommendation
	 * @param origRec the original Recommendation class
	 */
	public RecommendationResult(int confidence, String explaination, List<Asset> assets, boolean required, Recommendation origRec) {
		this.confidence = confidence;
		this.explanation = explaination;
		this.assets = assets;
		this.required = required;
		this.origRec = origRec;
	}

	public int getConfidence() {
		return confidence;
	}
	
	public String getExplanation() {
		return explanation;
	}
	
	
	public List<Asset> getAssetList() {
		return assets;
	}
	
	public boolean isRequired() {
		return required;
	}
	
	public Recommendation getOriginalRec() {
		return origRec;
	}
	
	@Override
	public Map<String, String> getTemplateTags() {
		Map<String,String> displayInfo = new HashMap<String,String>();
		displayInfo.put("Name", origRec.getName());
		displayInfo.put("Description", origRec.getDescription());
		displayInfo.put("Rationale",explanation);
		displayInfo.put("Confidence", String.valueOf(confidence));
		displayInfo.put("Summary", origRec.getSummary());
		return displayInfo;
	}

	@Override
	public int compareTo(RecommendationResult that) {
		int confidenceDiff = that.getConfidence() - this.confidence;
		if(confidenceDiff != 0) {
			return confidenceDiff;
		}
		return this.origRec.getName().compareTo(that.getOriginalRec().getName());
	}
	
	

}
