/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation;

import java.util.ArrayList;
import java.util.List;

import recommendation.asset.Asset;
import attribute.Attribute;

/**
 * A Builder for a Scenario.
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public class ScenarioBuilder {
	private List<Attribute> attributes;
	private int weight;
	private boolean required;
	private boolean stop;
	private boolean notRecommended;
	private List<Asset> assets;
	
	public ScenarioBuilder() {
		attributes = new ArrayList<Attribute>();
		weight = 0;
		required = false;
		stop = false;
		notRecommended = false;
		assets = new ArrayList<Asset>();
	}
	
	public void addAttribute(Attribute attr) {
		attributes.add(attr);
	}
	
	public Scenario buildScenario() {
		if(attributes.isEmpty()) {
			throw new IllegalStateException("Cannot build a scenario without at least one attribute");
		}
		return new Scenario(attributes,weight,required,stop,notRecommended,assets);
	}
	
	public void addAsset(Asset asset) {
		assets.add(asset);
	}
	
	public List<Asset> getAssets() {
		return assets;
	}

	public boolean isRequired() {
		return required;
	}

	public void setRequired(boolean required) {
		this.required = required;
	}

	public boolean isStop() {
		return stop;
	}

	public void setStop(boolean stop) {
		this.stop = stop;
	}

	public boolean isNotRecommended() {
		return notRecommended;
	}

	public void setNotRecommended(boolean notRecommended) {
		this.notRecommended = notRecommended;
	}

	public int getWeight() {
		return weight;
	}
	
	public void addWeight(int weight) {
		this.weight += weight;
	}
	
	public void removeWeight(int weight) {
		this.weight -= weight;
	}
}
