/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation.asset;

import java.util.Map;
import java.util.Set;

import recommendationView.Templateable;

/**
 * An Asset is a reference, such as a web link or simple text,
 * that assists the user in implementing a Recommendation.
 * Each Recommendation may have many Assets.
 * @author Wesley Ripley, Adam Talbot
 * @version 12/4/12
 */
public interface Asset extends Templateable{
	
	/**
	 * Gets the Map of content types to their contents
	 * @return A Map of Strings to Strings
	 */
	Map<String, String> getContents();

	/**
	 * The asset type
	 * @return the asset type of this asset
	 */
	AssetType getType();

	/**
	 * Gets the Set of content keys
	 * @return a Set of content key Strings
	 */
	Set<String> getContentKeys();
	
}
