/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendation.asset;

import java.util.HashSet;
import java.util.Set;

/**
 * Enumerates each possible Asset type.
 * @author Wesley Ripley, Adam Talbot
 * @version 2/20/13
 */
public enum AssetType {
	LINK("Link"), 
	ONLINE_IMAGE("Online Image"), 
	TEXT("Text");
	
	private String id;
	
	AssetType(String id) {
		this.id = id;
	}
	
	public String toString() {
		return id;
	}
	
	/**
	 * Finds the AssetType that matches the given id
	 * @param identifier a String id
	 * @return the matching AssetType, if it exists
	 */
	public static AssetType fromString(String identifier) {
		identifier = identifier.trim().toLowerCase();
		for(AssetType type : AssetType.values()) {
			if(identifier.equals(type.toString().toLowerCase())) {
				return type;
			}
		}
		throw new IllegalStateException("Invalid asset type");
	}
	
	/**
	 * Each AssetType has specific content identifiers (or keys)
	 * that apply.  This method returns the content keys that apply
	 * to this AssetType.
	 * @return a Set of content keys in String form.
	 */
	public Set<String> getContentKeys() {
		Set<String> contentKeys = new HashSet<String>();
		switch(this) {
		case LINK:
			contentKeys.add("url");
			contentKeys.add("text");
			break;
		case ONLINE_IMAGE:
			contentKeys.add("src");
			contentKeys.add("alt");
			contentKeys.add("caption");
			break;
		case TEXT:
			contentKeys.add("text");
			break;
		}
		return contentKeys;
	}

}
