/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package recommendationView;

import java.util.regex.Pattern;

/**
 * Generates strings for regex parsing.
 * @author Wesley Ripley, Adam Talbot
 * @version Nov 1, 2012
 */
public class TemplateParserPatterns {
	private String token;
	
	public TemplateParserPatterns(String token){
		this.token = token;
	}
	
	/**
	 * Generates a regex Pattern that looks for loops and stores
	 * the interior as capturing group 1.
	 * @param tag the identifier, e.g. "Recommendations"
	 * @return the Pattern for the Matcher.
	 */
/*	public Pattern loopFinder(String tag){
		String loop = ".*?" + token + tag + token +
		"([.\\n]*?)" + token + "End\\s" + tag + token + ".*";
		return Pattern.compile(loop, Pattern.MULTILINE);
	}
*/
	
	/**
	 * Generates a regex Pattern that looks for entire loops
	 * to be replaced.  No groups are captured.
	 * @param tag the identifier, e.g. "Assets"
	 * @return the Pattern for the Matcher.
	 */
/*	public Pattern loopReplacer(String tag){
		String loop =
			token + tag + token + "[.\\n]*?" +
			token + "End\\s" + tag + token;
		return Pattern.compile(loop, Pattern.MULTILINE);
	}
*/
	
	/**
	 * Generates a regex Pattern that looks for individual tags
	 * to be replaced.  No groups are captured.
	 * @param tag the identifier, e.g. "Name"
	 * @return the Pattern for the Matcher.
	 */
	public Pattern tagReplacer(String tag){
		String express =
			token + "(?i:" + tag + ")" + token;
		return Pattern.compile(express);
	}
	
	/**
	 * Generates a regex Pattern that looks for a variable
	 * and stores it in capturing group 1.
	 * @param tag the identifier, e.g. "Filename"
	 * @return the Pattern for the Matcher.
	 */
	public Pattern variableFinder(String tag){
		String express = token + tag +
		":\\s(.*?)" + token;
		return Pattern.compile(express);
	}
}
