/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package value;

import value.valueData.ValueType;

/**
 * An implementation of the Value class that represents a Boolean.
 * @author Wesley Ripley, Adam Talbot
 * @version 10/03/12
 */
public class BooleanValue implements Value {

	private boolean value;
	
	/**
	 * Constructor for a BooleanValue
	 * @param value Either true or false
	 */
	public BooleanValue(boolean value) {
		this.value = value;
	}
	
	/**
	 * Gets the boolean representation of this BooleanValue
	 * @return Either true or false
	 */
	public boolean getContents()
	{
		return value;
	}
	
	@Override
	public boolean equals(Object o) {
		if(!(o instanceof BooleanValue)) {
			return false;
		}
		BooleanValue other = (BooleanValue)o;
		return this.value == other.getContents();
	}

	@Override
	public boolean isMultipleValue() {
		return false;
	}

	@Override
	public boolean fitCriteria(Value val) {
		// If it isn't a BOOLEAN, return false.
		if (!val.getType().equals(ValueType.BOOLEAN)){
			return false;
		}
		// If it is, return true if they're both the same.
		return this.equals(val);
		
	}

	@Override
	public ValueType getType() {
		return ValueType.BOOLEAN;
	}
	
	@Override
	public void initialize() {
		// Doing anything here is a bit pointless.
		// This is an option if we really want to:
		// this.value = false;
	}

	@Override
	public boolean isEmpty() {
		return false;
	}

}
