/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package value;

import value.valueData.ValueType;

/**
 * Represents a Value of an Attribute.
 * Value is implemented in various subclasses for different
 * object types.
 * @author Wesley Ripley, Adam Talbot
 * @version 10/03/12
 */
public interface Value{

	/**
	 * Determines if the Value represents more than one Value.
	 * @return true if there are multiple Values, false if exactly zero or one
	 */
	public boolean isMultipleValue();
	
	/**
	 * Determines if the contents of a given Value overlap with this Value
	 * @param val The Value to be matched
	 * @return true if the Values match, else false
	 */
	public boolean fitCriteria(Value val);
	
	/**
	 * Provides the ValueType that corresponds with this Value.
	 * Used for AttributeDescriptions.
	 * @return a ValueType corresponding to the implemented Value type. 
	 */
	public ValueType getType();
	
	/**
	 * Removes all information from this Value.
	 * Use with caution.
	 */
	public void initialize();
	
	/**
	 * Checks to see if this Value is empty.
	 * @return true if empty.
	 */
	public boolean isEmpty();
}
