/*******************************************************************************
 * This file is part of the Software Process Configurator MQP
 * Project Members: Wesley Ripley, Adam Talbot.
 * Project Advisor: Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Wesley Ripley, Adam Talbot
 *******************************************************************************/

package value.valueData;

import value.BooleanValue;
import value.IntegerValue;
import value.StringValue;
import value.Value;

/**
 * Represents a type for any given Value.  Values that have
 * multiple Values give the type of their contained Values.
 * @author Wesley Ripley, Adam Talbot
 * @version 10/03/12
 */
public enum ValueType {
	INT, STRING, BOOLEAN;
	
	/**
	 * Constructs a Value relevant to this ValueType
	 * @param value The information to be made into a Value, in
	 * the form of a String no matter what the real type is
	 * @return a new Value with the given information
	 * @throws IllegalArgumentException if the given value doesn't make sense for
	 * this ValueType
	 */
	public Value makeValue(String value) throws IllegalArgumentException {
		switch(this) {
		case INT:
			try{
				return new IntegerValue(Integer.parseInt(value));
			} catch (NumberFormatException e) {
				throw new IllegalArgumentException("Integer values must be an integer");
			}
		case STRING:
			return new StringValue(value);
		case BOOLEAN:
			if(value.equalsIgnoreCase("true")) {
				return new BooleanValue(true);
			} else if(value.equalsIgnoreCase("false")) {
				return new BooleanValue(false);
			} else {
				throw new IllegalArgumentException("Boolean values must be either true or false");
			}
		default:
			throw new IllegalArgumentException("Illegal value type");
		}
	}
}