/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package xmlParser;

import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import app.SPC;

import database.Database;
import dialog.Dialog;

/** this class handles creating a Dialog and parsing an xml file into a Dialog object
 * this xml file contains a list of SubDialog file names. each SubDailog is parsed
 * and added to the Dialog
 * 
 * @author jake todaro
 * @version 1/13/12
 */

public class DialogParser {
	
	/** Parse a dialog xml file into a Dialog object
	 * 
	 * @param fileName - the name of the Dialog file
	 */
	public static void parseDialog(String fileName){
		final Element dialogElement = XMLParser.getDocumentElement(fileName);
		String dbName ="";
		//Saves database name
		dbName = ((Element) dialogElement.getElementsByTagName("Database").item(0)).getAttribute("name");
		parseDialog(dialogElement,SPC.setDB(dbName));
	}
	
	/**
	 * For test purposes only
	 */
	public static void parseDialog(String fileName, Database database) {
		parseDialog(XMLParser.getDocumentElement(fileName),database);
	}
	
	private static void parseDialog(Element dialogElement, Database database) {
		Dialog.startDialog(database);
		
		final NodeList subDialogNodeList = dialogElement.getElementsByTagName("SubDialog");
		
		for(int i = 0; i < subDialogNodeList.getLength(); i++){
			String subDialog = ((Element) subDialogNodeList.item(i)).getAttribute("name");
			subDialog += ".xml";
			
			Dialog.addSubDialog(SubDialogParser.parseSubDialog(subDialog));
		}
	}
	
}
