/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package xmlParser;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

/** this class handles general XML parsing and is responsible for
 * converting an XML file into an XML Element ready for parsing
 * 
 * @author jake todaro
 * 
 * @version 12/23/11
 */

public class XMLParser {
	
	/**
	 * parse the xml file into a DOM representation
	 * 
	 * @param fileName
	 *            - the name of the xml file to be parsed
	 * @return the Document in DOM representation
	 */
	private static Document parseXMLFile(String fileName) {

		Document domDocument = null;
		final DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();

		try {
			// Using factory get an instance of document builder
			final DocumentBuilder db = dbf.newDocumentBuilder();
			InputStream is = new FileInputStream(fileName);
			// parse using builder to get DOM representation of the XML file
			domDocument = db.parse(is);

		} catch (ParserConfigurationException pce) {
			pce.printStackTrace();
		} catch (SAXException se) {
			se.printStackTrace();
		} catch (IOException ioe) {
			ioe.printStackTrace();
		}

		return domDocument;
	}

	/**
	 * parse the DOM representation and create the appropriate SubDialog object
	 * 
	 * @param domDocument
	 *            - the DOM representation of the document
	 * @param dialog
	 *            - the Dialog to add this newly parsed SubDialog to
	 * @return 
	 */
	private static Element parseDocument(Document domDocument) {

		// get the SubDialog element
		final Element element = domDocument.getDocumentElement();

		return element;
	}
	
	/** return the document element for the specified XML file
	 * 
	 * @param fileName - the name of the XML file
	 * @return the document element of the XML file
	 */
	public static Element getDocumentElement(String fileName){
		return parseDocument(parseXMLFile(fileName));
	}
}
