/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package booleanExpression;

import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.Test;

public class BooleanAndExpressionTest {
	
	public static TrueBooleanAtom TRUE = null;
	public static FalseBooleanAtom FALSE = null;
	
	@Before
	public void setup(){
		TRUE = new TrueBooleanAtom();
		FALSE = new FalseBooleanAtom();
	}
	
	/** test that the test atoms return the correct values */
	@Test
	public void testAtoms(){
		assertTrue(TRUE.value());
		assertFalse(FALSE.value());
	}
	
	/** test that the AndExpression object initializes correctly */
	@Test
	public void testInitialization(){
		AndExpression and = new AndExpression();
		assertEquals(0, and.getAtomList().size());
	}
	
	/** test that the AndExpression object can add atoms */
	@Test
	public void testAddAtom(){
		AndExpression and = new AndExpression();
		and.addAtom(TRUE);
		assertEquals(1, and.getAtomList().size());
		assertEquals(TRUE, and.getAtomList().get(0));
	}
	
	/** test that an AndExpression with a single atom returns
	 * the correct value */
	@Test
	public void testSingleAtom(){
		AndExpression and = new AndExpression();
		and.addAtom(TRUE);
		assertTrue(and.value());
		
		and = new AndExpression();
		and.addAtom(FALSE);
		assertFalse(and.value());
	}
	
	/** test that an AndExpression with a multiple atoms returns
	 * the correct value */
	@Test
	public void tesMultipleAtoms(){
		AndExpression and = new AndExpression();
		and.addAtom(TRUE);
		and.addAtom(TRUE);
		assertTrue(and.value());
		
		and.getAtomList().clear();
		and.addAtom(TRUE);
		and.addAtom(FALSE);
		assertFalse(and.value());
		
		and.getAtomList().clear();
		and.addAtom(FALSE);
		and.addAtom(TRUE);
		assertFalse(and.value());
		
		and.getAtomList().clear();
		and.addAtom(FALSE);
		and.addAtom(FALSE);
		assertFalse(and.value());
	}
	
	/** test that an AndExpression with a multiple atoms returns
	 * the correct value */
	@Test
	public void testComplexAtoms(){
		AndExpression and = new AndExpression();
		and.addAtom(TRUE);
		OrExpression or = new OrExpression();
		or.addAtom(FALSE);
		or.addAtom(TRUE);
		and.addAtom(or);
		assertTrue(and.value());
		
		and.getAtomList().clear();
		and.addAtom(TRUE);
		or.getAtomList().clear();
		or.addAtom(FALSE);
		or.addAtom(FALSE);
		and.addAtom(or);
		assertFalse(and.value());
	}
}