/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package booleanExpression;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Before;
import org.junit.Test;

import dialog.Answer;
import dialog.Question;

public class BooleanNotExpressionTest {

	public static TrueBooleanAtom TRUE = null;
	public static FalseBooleanAtom FALSE = null;
	
	@Before
	public void setup(){
		TRUE = new TrueBooleanAtom();
		FALSE = new FalseBooleanAtom();
	}
	
	/** test that the test atoms return the correct values */
	@Test
	public void testAtoms(){
		assertTrue(TRUE.value());
		assertFalse(FALSE.value());
	}
	
	/** test that the NotExpression works */
	@Test
	public void testNot(){
		NotExpression notTrue = new NotExpression(TRUE);
		NotExpression notFalse = new NotExpression(FALSE);
		
		assertFalse(notTrue.value());
		assertTrue(notFalse.value());
	}
	
	/** test that the notExpression works for Answer objects */
	@Test
	public void testNotAnswer(){	
		Question question = new Question("q");
		question.setID("1");
		Answer a1 = new Answer(1, "1");
		Answer a2 = new Answer(2, "2");
		Answer a3 = new Answer(3, "3");
		question.addAnswer(a1);
		question.addAnswer(a2);
		question.addAnswer(a3);
		
		NotExpression nota2 = new NotExpression(a2);
		NotExpression nota3 = new NotExpression(a3);
		
		assertFalse(nota3.value());
		
		a2.select();
		
		assertFalse(nota2.value());
		assertTrue(nota3.value());
	}
}
