
package database;

import static org.junit.Assert.*;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import recommendation.BasicRecommendation;
import recommendation.Scenario;
import recommendation.Recommendation;
import value.BooleanValue;
import value.IntegerValue;
import attribute.Attribute;

public class DBTest {
	
	private Recommendation testRec;
	private Database db;
	private String dbLoc;
	@SuppressWarnings("serial")
	private final static List<Scenario> testRecScenarios = 
			new ArrayList<Scenario>() {{
		add(new Scenario(new Attribute("Team Size",
				new IntegerValue(10,20)),3,false));
		add(new Scenario(new Attribute("# Offices",
				new IntegerValue(1))));
		add(new Scenario(new Attribute("Government",
				new BooleanValue(false)),0,true));
	}};
	
	@Before
	public void setUp() throws Exception {
		testRec = new BasicRecommendation("testRec",testRecScenarios,"You should use the New Process!");
		db = new Db4oDatabase();
		dbLoc = "test/database/dbTest";
		File dbclean = new File(dbLoc);
		dbclean.delete();
	}
	
	@Test
	public void testCreation(){
		db.use(dbLoc);
		List<Recommendation> query = new ArrayList<Recommendation>();
		query.addAll(db.getAllRecommendations());
		db.close();
		assertTrue(query.isEmpty());
	}
	
	@Test
	public void testStorage() {
		db.use(dbLoc);
		db.store(testRec);
		db.close();
		db.use(dbLoc);
		List<Recommendation> query = new ArrayList<Recommendation>();
		query.addAll(db.getAllRecommendations());
		assertFalse(query.isEmpty());
		assertEquals(1,query.size());
		Recommendation rec = query.get(0);
		assertEquals("testRec",rec.getName());
		assertEquals("You should use the New Process!",rec.getDescription());
		List<Scenario> scenarios = ((BasicRecommendation)rec).getScenarios();
		assertEquals(3,scenarios.size());
		for(int i = 0; i < 3; i++) {
			Scenario expected = testRecScenarios.get(i);
			Scenario actual = scenarios.get(i);
			assertEquals(expected.getWeight(),actual.getWeight());
			assertEquals(expected.isRequired(),actual.isRequired());
			assertEquals(expected.getAttributes(),actual.getAttributes());
		}
		db.close();
	}
	
	@Test
	public void testDeletion(){
		db.use(dbLoc);
		db.store(testRec);
		List<Recommendation> query = new ArrayList<Recommendation>();
		query.addAll(db.getAllRecommendations());
		assertFalse(query.isEmpty());
		db.delete(testRec);
		query.clear();
		query.addAll(db.getAllRecommendations());
		db.close();
		assertTrue(query.isEmpty());
	}
	

}
