
package dsl.antlr;

import static org.junit.Assert.assertEquals;

import java.io.IOException;
import java.io.StringReader;

import org.antlr.runtime.ANTLRReaderStream;
import org.antlr.runtime.Token;
import org.junit.Test;

public class DSLLexerTests {

	@Test
	public void testEmptyStreamYieldsEOF() throws IOException
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("")));
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}
	
	@Test
	public void testWhitespace() throws IOException
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("  \n\t\f\r\n")));
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}
	
	@Test
	public void testSectionReservedWords() throws IOException
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("Recommendation:Category:Summary:Description:Scenario:")));
		assertEquals(DSLLexer.REC, lexer.nextToken().getType());
		assertEquals(DSLLexer.CATEGORY, lexer.nextToken().getType());
		assertEquals(DSLLexer.SUMMARY, lexer.nextToken().getType());
		assertEquals(DSLLexer.DESC, lexer.nextToken().getType());
		assertEquals(DSLLexer.SCENARIO, lexer.nextToken().getType());
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}
	
	@Test
	public void testGivenThenReservedWords() throws IOException
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("Given Then")));
		assertEquals(DSLLexer.GIVEN, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.THEN, lexer.nextToken().getType());
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}
	
	@Test
	public void testActionReservedWords() throws IOException
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("Add Remove confidence Stop Make Required Do not recommend")));
		assertEquals(DSLLexer.ADD, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.REMOVE, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.CONFIDENCE, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.STOP, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.MAKE, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.REQUIRED, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.DO, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.NOT, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.RECWORD, lexer.nextToken().getType());
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}
	
	@Test
	public void testLogicReservedWords() throws IOException
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("and And true false")));
		assertEquals(DSLLexer.AND, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.AND, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.TRUE, lexer.nextToken().getType());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		assertEquals(DSLLexer.FALSE, lexer.nextToken().getType());
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}
	
	@Test
	public void testAsset() throws Exception
	{
		DSLLexer lexer = new DSLLexer(new ANTLRReaderStream(new StringReader("Link Asset: Text Asset: Book Asset: Online Image Asset:")));
		Token t = lexer.nextToken();
		assertEquals(DSLLexer.ASSET, t.getType());
		assertEquals("Link Asset:",t.getText());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		t = lexer.nextToken();
		assertEquals(DSLLexer.ASSET, t.getType());
		assertEquals("Text Asset:",t.getText());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		t = lexer.nextToken();
		assertEquals(DSLLexer.ASSET, t.getType());
		assertEquals("Book Asset:",t.getText());
		assertEquals(DSLLexer.WS, lexer.nextToken().getType());
		t = lexer.nextToken();
		assertEquals(DSLLexer.ASSET, t.getType());
		assertEquals("Online Image Asset:",t.getText());
		assertEquals(DSLLexer.EOF, lexer.nextToken().getType());
	}	

}
