
package recommendation;

import static org.junit.Assert.*;

import java.util.Map;

import org.junit.Before;
import org.junit.Test;

import recommendation.asset.Asset;
import recommendation.asset.AssetBuilder;
import recommendation.asset.AssetType;

public class AssetBuilderTest {
	
	AssetBuilder assetBuilder;
	
	@Before
	public void setUp() {
		assetBuilder = new AssetBuilder();
	}

	@Test
	public void testSetIdentifierWithAsset(){
		assetBuilder.setIdentifier("Link Asset:");
		assertEquals("link",assetBuilder.getIdentifier());
		assetBuilder.setIdentifier("Online Image Asset:");
		assertEquals("online image",assetBuilder.getIdentifier());
		assetBuilder.setIdentifier("Book");
		assertEquals("book",assetBuilder.getIdentifier());
	}
	
	@Test
	public void testBuildLinkAsset() {
		assetBuilder.setIdentifier("Link");
		assetBuilder.setContent("URL: http://wesleyripley.com/\n" +
								"Text: A Webpage");
		Asset asset = assetBuilder.buildAsset();
		assertEquals(AssetType.LINK,asset.getType());
		Map<String,String> content = asset.getContents();
		assertEquals(2, content.size());
		assertTrue(content.keySet().contains("url"));
		assertTrue(content.keySet().contains("text"));
		assertEquals("http://wesleyripley.com/",content.get("url"));
		assertEquals("A Webpage",content.get("text"));
	}
	
	@Test
	public void testBuildOnlineImageAsset() {
		assetBuilder.setIdentifier("Online Image");
		assetBuilder.setContent("src: http://images3.wikia.nocookie.net/__cb20060212075613/looneytunes/images/f/fc/Daffy_duck.gif\n" +
								"alt: Daffy Duck\n" +
								"caption: Daffy Duck is a\nvery cool duck");
		Asset asset = assetBuilder.buildAsset();
		assertEquals(AssetType.ONLINE_IMAGE,asset.getType());
		Map<String,String> content = asset.getContents();
		assertEquals(3, content.size());
		assertTrue(content.keySet().contains("src"));
		assertTrue(content.keySet().contains("alt"));
		assertTrue(content.keySet().contains("caption"));
		assertEquals("http://images3.wikia.nocookie.net/__cb20060212075613/looneytunes/images/f/fc/Daffy_duck.gif",content.get("src"));
		assertEquals("Daffy Duck",content.get("alt"));
		assertEquals("Daffy Duck is a\nvery cool duck",content.get("caption"));
	}
	
	@Test
	public void testBuildTextAsset() {
		assetBuilder.setIdentifier("Text");
		assetBuilder.setContent("Text: This is a whole lot\n" +
								"  of cool text.\n" +
								"Couldbe: anything$^$%(*&^)^%@#$!_");
		Asset asset = assetBuilder.buildAsset();
		assertEquals(AssetType.TEXT,asset.getType());
		Map<String,String> content = asset.getContents();
		assertEquals(1, content.size());
		assertTrue(content.keySet().contains("text"));
		assertEquals("This is a whole lot\n" +
								"  of cool text.\n" +
								"Couldbe: anything$^$%(*&^)^%@#$!_",content.get("text"));
	}

}
