package recommendation;

import static org.junit.Assert.*;

import java.util.ArrayList;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import value.BooleanValue;
import value.IntegerValue;

import attribute.Attribute;
@SuppressWarnings("serial")
public class RecommendationTests {

	private Recommendation testRec;
	private final static List<Scenario> testRecProperties = 
			new ArrayList<Scenario>() {{
		add(new Scenario(new Attribute("Team Size",
				new IntegerValue(10, 20)),3,false));
		add(new Scenario(new Attribute("# Offices",
				new IntegerValue(1))));
		add(new Scenario(new Attribute("Government",
				new BooleanValue(false)),0,true));
		
	}};
	
	@Before
	public void setUp() throws Exception {
		testRec = new BasicRecommendation("testRec",testRecProperties,"You should use the New Process!");
	}

	@Test
	public void testProjectThatFits() {
		Constraints constraints = new Constraints(new ArrayList<Attribute>() {{
			add(new Attribute("# Offices",new IntegerValue(1)));
			add(new Attribute("Team Size", new IntegerValue(15)));
			add(new Attribute("Iteration Length", new IntegerValue(30)));
			add(new Attribute("Government", new BooleanValue(false)));
		}});
		RecommendationResult recResult = testRec.evaluateScenario(constraints);
		assertEquals(4, recResult.getConfidence());
	}
	
	@Test
	public void testProjectSomewhatFits() {
		Constraints constraints = new Constraints(new ArrayList<Attribute>() {{
			add(new Attribute("Iteration Length", new IntegerValue(30)));
			add(new Attribute("# Offices",new IntegerValue(5)));
			add(new Attribute("Government", new BooleanValue(false)));
			add(new Attribute("Team Size", new IntegerValue(15)));
		}});
		RecommendationResult recResult = testRec.evaluateScenario(constraints);
		assertEquals(3, recResult.getConfidence());
	}
	
	@Test
	public void testProjectDoesntFitButHasRequirement() {
		Constraints constraints = new Constraints(new ArrayList<Attribute>() {{
			add(new Attribute("# Offices",new IntegerValue(5)));
			add(new Attribute("Team Size", new IntegerValue(30)));
			add(new Attribute("Iteration Length", new IntegerValue(30)));
			add(new Attribute("Government", new BooleanValue(false)));
		}});
		RecommendationResult recResult = testRec.evaluateScenario(constraints);
		assertEquals(0, recResult.getConfidence());
	}
	
	@Test
	public void testProjectDoesntFitFailsRequirement() {
		Constraints constraints = new Constraints(new ArrayList<Attribute>() {{
			add(new Attribute("# Offices",new IntegerValue(1)));
			add(new Attribute("Team Size", new IntegerValue(10)));
			add(new Attribute("Iteration Length", new IntegerValue(30)));
			add(new Attribute("Government", new BooleanValue(true)));
		}});
		RecommendationResult recResult = testRec.evaluateScenario(constraints);
		assertEquals(4, recResult.getConfidence());
		assertFalse(recResult.isRequired());
	}
	
	

}
