
package recommendationView;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.junit.Before;
import org.junit.Test;

import attribute.Attribute;

import recommendation.BasicRecommendation;
import recommendation.Scenario;
import recommendation.asset.Asset;
import recommendation.asset.AssetStore;
import recommendation.asset.AssetType;
import value.IntegerValue;

public class ReconstructorTests {
	
	List<Scenario> scenList;
	List<Asset> assetList;
	List<String> catList;
	BasicRecommendation rec;
	RecommendationReconstructor recRecon;
	
	@Before
	public void setUp(){
		// Prepare two sample Assets
		assetList = new ArrayList<Asset>();
		Map<String, String> textAssetMap = new HashMap<String, String>();
		textAssetMap.put("text", "Sample Text");
		assetList.add(new AssetStore(AssetType.TEXT, textAssetMap));
		Map<String, String> linkAssetMap = new HashMap<String, String>();
		linkAssetMap.put("url", "www.sample.com");
		linkAssetMap.put("text", "Sample Site");
		assetList.add(new AssetStore(AssetType.LINK, linkAssetMap));
		// Prepare some sample Scenarios
		scenList = new ArrayList<Scenario>();
		List<Attribute> attList1 = new ArrayList<Attribute>();
		IntegerValue notValue = new IntegerValue();
		notValue.addNot(1);
		IntegerValue lotsOfValues = new IntegerValue();
		lotsOfValues.addSingle(1);
		lotsOfValues.addSingle(3);
		lotsOfValues.addLessThan(-5);
		lotsOfValues.addGreaterThan(10, true);
		lotsOfValues.addBetween(6, 7);
		attList1.add(new Attribute("attributeOne", notValue));
		attList1.add(new Attribute("attributeTwo", lotsOfValues));
		scenList.add(new Scenario(attList1, 30, true, true, true, assetList));
		// Prepare sample Categories
		catList = new ArrayList<String>();
		// Construct the Recommendation
		rec = new BasicRecommendation(
				"Sample Recommendation",
				scenList,
				assetList,
				"This is the Recommendation's Description.\n" +
				"It should be assumed that it can span multiple lines.",
				"This is the Recommendation's Summary.",
				catList);
		recRecon = new RecommendationReconstructor(rec);
		// Make sure the file is not already there.
		String fileName = rec.getName();
		fileName = fileName.replaceAll("[^a-zA-Z0-9]", "");
		File outputFile = new File(System.getProperty("user.dir") +
				"/recommendations/" + fileName + ".txt");
		outputFile.delete();
	}
	
	@Test
	public void testReconstructor(){
		recRecon.reconstruct();
	}

}
