package recommendationView;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import recommendation.BasicRecommendation;
import recommendation.Constraints;
import recommendation.Recommendation;
import recommendation.RecommendationResult;
import recommendation.Scenario;
import recommendation.asset.Asset;
import recommendation.asset.AssetStore;
import recommendation.asset.AssetType;
import value.BooleanValue;
import value.IntegerValue;
import attribute.Attribute;

@SuppressWarnings("serial")
public class TemplateParserTests {

	private Recommendation testRec1;
	private Recommendation testRec2;
	private TemplateParser testParser;
	
	private List<RecommendationResult> recList = new ArrayList<RecommendationResult>();
	
	private final static List<Scenario> testRecProps1 = 
		new ArrayList<Scenario>() {{
			add(new Scenario(new Attribute("Team Size",
					new IntegerValue(10, 20)),3,false));
			add(new Scenario(new Attribute("# Offices",
					new IntegerValue(1))));
			add(new Scenario(new Attribute("Government",
					new BooleanValue(false)),0,true));
		}};
	private final static List<Scenario> testRecProps2 = 
		new ArrayList<Scenario>() {{
			add(new Scenario(new Attribute("Use XP",
					new BooleanValue(true)),0,true));
		}};
	private final static List<Asset> testAssets1 = 
		new ArrayList<Asset>(){{
			add(new AssetStore(AssetType.LINK,new HashMap<String,String>() {{
				put("url","www.google.com");
				put("text","Google");
			}}));
		}};
	private final static List<Asset> testAssets2 = 
		new ArrayList<Asset>(){{
			add(new AssetStore(AssetType.LINK,new HashMap<String,String>() {{
				put("url","www.wolframalpha.com");
				put("text","Wolfram Alpha");
			}}));
			add(new AssetStore(AssetType.TEXT,new HashMap<String,String>() {{
				put("text","Use a calculator to do math.");
			}}));
		}};
	

	@Before
	public void setUp() throws Exception {
		testRec1 = new BasicRecommendation("testRec1",testRecProps1,testAssets1,"You should use the New Process!");
		testRec2 = new BasicRecommendation("testRec2",testRecProps2,testAssets2,"You should use XP!");
		testParser = new TemplateParser();
		Constraints constraints = new Constraints();
		recList.add(testRec1.evaluateScenario(constraints));
		recList.add(testRec2.evaluateScenario(constraints));
	}

	@Test
	public void testParser() throws IOException{
		System.out.println(testParser.parseTemplate(recList).getAbsolutePath());
		
	}
	
	

}
