
package value;

import static org.junit.Assert.*;

import org.junit.Test;

import value.valueData.ValueType;

/**
 * Absurdly comprehensive testing of the Value classes.
 * @author Wesley Ripley, Adam Talbot
 * @version Jan 16, 2013
 */
public class ValueTests {
	
	@Test
	public void testIntType(){
		Value value = new IntegerValue();
		assertEquals(value.getType(), ValueType.INT);
	}
	
	@Test
	public void testStringType(){
		Value value = new StringValue();
		assertEquals(value.getType(), ValueType.STRING);
	}
	
	@Test
	public void testBooleanType(){
		Value value = new BooleanValue(true);
		assertEquals(value.getType(), ValueType.BOOLEAN);
	}
	
	@Test
	public void testBooleanMultiple(){
		Value value = new BooleanValue(false);
		assertFalse(value.isMultipleValue());
	}
	
	@Test
	public void testBooleanContents(){
		BooleanValue value1 = new BooleanValue(true);
		BooleanValue value2 = new BooleanValue(false);
		assertTrue(value1.getContents());
		assertFalse(value2.getContents());
	}
	
	@Test
	public void testBooleanMatches(){
		Value value1 = new BooleanValue(true);
		Value value2 = new BooleanValue(false);
		Value value3 = new BooleanValue(true);
		Value value4 = new StringValue("string");
		assertFalse(value1.fitCriteria(value2));
		assertTrue(value1.fitCriteria(value3));
		assertFalse(value1.fitCriteria(value4));
	}
	
	@Test
	public void testStringMultiples(){
		StringValue value0 = new StringValue();
		StringValue value1 = new StringValue("one");
		StringValue value2 = new StringValue();
		value2.addString("first");
		value2.addString("second");
		assertFalse(value0.isMultipleValue());
		assertFalse(value1.isMultipleValue());
		assertTrue(value2.isMultipleValue());
	}
	
	@Test
	public void testStringMatches(){
		StringValue value0 = new StringValue();
		StringValue value1 = new StringValue("one");
		StringValue value2 = new StringValue("first");
		StringValue value3 = new StringValue("two");
		value3.addString("one");
		IntegerValue value4 = new IntegerValue();
		
		assertFalse(value0.fitCriteria(value1));
		assertFalse(value1.fitCriteria(value0));
		assertFalse(value1.fitCriteria(value2));
		assertTrue(value1.fitCriteria(value3));
		assertFalse(value1.fitCriteria(value4));
	}
	
	@Test
	public void testStringInit(){
		StringValue value1 = new StringValue("before");
		value1.initialize();
		value1.addString("after");
		assertFalse(value1.getContents().contains("before"));
		assertTrue(value1.getContents().contains("after"));
	}
	
	@Test
	public void testIntInit(){
		IntegerValue value1 = new IntegerValue();
		value1.addSingle(1);
		value1.addNot(3);
		value1.initialize();
		value1.addSingle(5);
		value1.addBetween(8, 11);
		
		assertTrue(value1.getContents().size() == 2);
	}
	
	@Test(expected = IllegalStateException.class)
	public void testIllegalIntValue1(){
		IntegerValue value1 = new IntegerValue();
		value1.addBetween(5, 0);
	}
	
	@Test(expected = IllegalStateException.class)
	public void testIllegalIntValue2(){
		IntegerValue value1 = new IntegerValue();
		value1.addBetween(0, 0);
	}
	
	@Test(expected = IllegalStateException.class)
	public void testIllegalIntValue3(){
		IntegerValue value1 = new IntegerValue();
		value1.addBetween(0, -5, false);
	}
	
	@Test(expected = IllegalStateException.class)
	public void testIllegalIntValue4(){
		IntegerValue value1 = new IntegerValue();
		value1.addBetween(10, 10, false);
	}
	
	@Test
	public void testNotAnIntFit(){
		Value value1 = new IntegerValue(1);
		Value value2 = new StringValue("failure");
		assertFalse(value1.fitCriteria(value2));
	}
	
	@Test
	public void testCommonIntFits(){
		Value value1 = new IntegerValue(1);
		Value value2 = new IntegerValue(0, 5);
		Value value3 = new IntegerValue(3);
		Value value4 = new IntegerValue(3, 5);
		Value value5 = new IntegerValue(1);
		
		assertTrue(value1.fitCriteria(value2));
		assertTrue(value2.fitCriteria(value1));
		assertTrue(value3.fitCriteria(value4));
		assertTrue(value4.fitCriteria(value3));
		assertTrue(value1.fitCriteria(value5));
		assertFalse(value1.fitCriteria(value3));
		assertFalse(value1.fitCriteria(value4));
		assertFalse(value4.fitCriteria(value1));
	}
	
	@Test
	public void testMultiInts(){
		IntegerValue value1 = new IntegerValue();
		IntegerValue value2 = new IntegerValue();
		IntegerValue value3 = new IntegerValue();
		IntegerValue value4 = new IntegerValue();
		IntegerValue value5 = new IntegerValue();
		IntegerValue value6 = new IntegerValue();
		IntegerValue value7 = new IntegerValue();
		value2.addSingle(1);
		value3.addSingle(0);
		value3.addSingle(5);
		value4.addNot(6);
		value5.addLessThan(2);
		value6.addGreaterThan(6, true);
		value7.addBetween(0, 10);
		
		assertFalse(value1.isMultipleValue());
		assertFalse(value2.isMultipleValue());
		assertTrue(value3.isMultipleValue());
		assertTrue(value4.isMultipleValue());
		assertTrue(value5.isMultipleValue());
		assertTrue(value6.isMultipleValue());
		assertTrue(value7.isMultipleValue());
	}
	
	@Test
	public void testSingleIntFits(){
		IntegerValue value1 = new IntegerValue();
		value1.addSingle(0);
		// False Values
		IntegerValue valueFalse1 = new IntegerValue();
		valueFalse1.addSingle(1);
		valueFalse1.addLessThan(0);
		valueFalse1.addGreaterThan(0);
		valueFalse1.addNot(0);
		IntegerValue valueFalse2 = new IntegerValue();
		valueFalse2.addGreaterThan(3, true);
		valueFalse2.addLessThan(-5, true);
		valueFalse2.addBetween(-4, -1, false);
		valueFalse2.addBetween(1, 2);
		// True Values
		IntegerValue valueTrue1 = new IntegerValue();
		IntegerValue valueTrue2 = new IntegerValue();
		IntegerValue valueTrue3 = new IntegerValue();
		IntegerValue valueTrue4 = new IntegerValue();
		IntegerValue valueTrue5 = new IntegerValue();
		IntegerValue valueTrue6 = new IntegerValue();
		IntegerValue valueTrue7 = new IntegerValue();
		IntegerValue valueTrue8 = new IntegerValue();
		valueTrue1.addLessThan(0, true);
		valueTrue2.addGreaterThan(0, true);
		valueTrue3.addLessThan(1);
		valueTrue4.addGreaterThan(-1);
		valueTrue5.addBetween(-5, 5);
		valueTrue6.addBetween(0, 5, true);
		valueTrue7.addBetween(-5, 0, true);
		valueTrue8.addNot(5);
		// Testing, one direction
		assertFalse(value1.fitCriteria(valueFalse1));
		assertFalse(value1.fitCriteria(valueFalse2));
		assertTrue(value1.fitCriteria(valueTrue1));
		assertTrue(value1.fitCriteria(valueTrue2));
		assertTrue(value1.fitCriteria(valueTrue3));
		assertTrue(value1.fitCriteria(valueTrue4));
		assertTrue(value1.fitCriteria(valueTrue5));
		assertTrue(value1.fitCriteria(valueTrue6));
		assertTrue(value1.fitCriteria(valueTrue7));
		assertTrue(value1.fitCriteria(valueTrue8));
		// Testing, other direction
		assertFalse(valueFalse1.fitCriteria(value1));
		assertFalse(valueFalse2.fitCriteria(value1));
		assertTrue(valueTrue1.fitCriteria(value1));
		assertTrue(valueTrue2.fitCriteria(value1));
		assertTrue(valueTrue3.fitCriteria(value1));
		assertTrue(valueTrue4.fitCriteria(value1));
		assertTrue(valueTrue5.fitCriteria(value1));
		assertTrue(valueTrue6.fitCriteria(value1));
		assertTrue(valueTrue7.fitCriteria(value1));
		assertTrue(valueTrue8.fitCriteria(value1));
	}
	
	@Test
	public void testLessThanIntFits(){
		IntegerValue value1 = new IntegerValue();
		IntegerValue value2 = new IntegerValue();
		value1.addLessThan(0, false);
		value2.addLessThan(0, true);
		// False Values
		IntegerValue valueFalse1 = new IntegerValue();
		IntegerValue valueFalse2 = new IntegerValue();
		valueFalse1.addSingle(1);
		valueFalse1.addGreaterThan(1);
		valueFalse2.addBetween(1, 5);
		// Special Case
		IntegerValue valueSpecial1 = new IntegerValue();
		IntegerValue valueSpecial2 = new IntegerValue();
		IntegerValue valueSpecial3 = new IntegerValue();
		valueSpecial1.addSingle(0);
		valueSpecial2.addGreaterThan(0, true);
		valueSpecial3.addBetween(0, 5, true);
		// True Values
		IntegerValue valueTrue1 = new IntegerValue();
		IntegerValue valueTrue2 = new IntegerValue();
		IntegerValue valueTrue3 = new IntegerValue();
		IntegerValue valueTrue4 = new IntegerValue();
		IntegerValue valueTrue5 = new IntegerValue();
		valueTrue1.addSingle(-1);
		valueTrue2.addLessThan(5);
		valueTrue3.addNot(0);
		valueTrue4.addNot(5);
		valueTrue5.addGreaterThan(-5);
		// Testing, direction 1
		assertFalse(value1.fitCriteria(valueFalse1));
		assertFalse(value1.fitCriteria(valueFalse2));
		assertFalse(value1.fitCriteria(valueSpecial1));
		assertFalse(value1.fitCriteria(valueSpecial2));
		assertFalse(value1.fitCriteria(valueSpecial3));
		assertTrue(value2.fitCriteria(valueSpecial1));
		assertTrue(value2.fitCriteria(valueSpecial2));
		assertTrue(value2.fitCriteria(valueSpecial3));
		assertTrue(value1.fitCriteria(valueTrue1));
		assertTrue(value1.fitCriteria(valueTrue2));
		assertTrue(value1.fitCriteria(valueTrue3));
		assertTrue(value1.fitCriteria(valueTrue4));
		assertTrue(value1.fitCriteria(valueTrue5));
		// Testing, direction 2
		assertFalse(valueFalse1.fitCriteria(value1));
		assertFalse(valueFalse2.fitCriteria(value1));
		assertFalse(valueSpecial1.fitCriteria(value1));
		assertFalse(valueSpecial2.fitCriteria(value1));
		assertFalse(valueSpecial3.fitCriteria(value1));
		assertTrue(valueSpecial1.fitCriteria(value2));
		assertTrue(valueSpecial2.fitCriteria(value2));
		assertTrue(valueSpecial3.fitCriteria(value2));
		assertTrue(valueTrue1.fitCriteria(value1));
		assertTrue(valueTrue2.fitCriteria(value1));
		assertTrue(valueTrue3.fitCriteria(value1));
		assertTrue(valueTrue4.fitCriteria(value1));
		assertTrue(valueTrue5.fitCriteria(value1));
	}
	
	@Test
	public void testGreaterThanIntFits(){
		IntegerValue value1 = new IntegerValue();
		IntegerValue value2 = new IntegerValue();
		value1.addGreaterThan(0, false);
		value2.addGreaterThan(0, true);
		// False Values
		IntegerValue valueFalse1 = new IntegerValue();
		IntegerValue valueFalse2 = new IntegerValue();
		valueFalse1.addSingle(-1);
		valueFalse1.addLessThan(-1);
		valueFalse2.addBetween(-5, -1);
		// Special Case
		IntegerValue valueSpecial1 = new IntegerValue();
		IntegerValue valueSpecial2 = new IntegerValue();
		IntegerValue valueSpecial3 = new IntegerValue();
		valueSpecial1.addSingle(0);
		valueSpecial2.addLessThan(0, true);
		valueSpecial3.addBetween(-5, 0, true);
		// True Values
		IntegerValue valueTrue1 = new IntegerValue();
		IntegerValue valueTrue2 = new IntegerValue();
		IntegerValue valueTrue3 = new IntegerValue();
		IntegerValue valueTrue4 = new IntegerValue();
		IntegerValue valueTrue5 = new IntegerValue();
		valueTrue1.addSingle(1);
		valueTrue2.addGreaterThan(-5);
		valueTrue3.addNot(0);
		valueTrue4.addNot(-5);
		valueTrue5.addLessThan(5);
		// Testing, direction 1
		assertFalse(value1.fitCriteria(valueFalse1));
		assertFalse(value1.fitCriteria(valueFalse2));
		assertFalse(value1.fitCriteria(valueSpecial1));
		assertFalse(value1.fitCriteria(valueSpecial2));
		assertFalse(value1.fitCriteria(valueSpecial3));
		assertTrue(value2.fitCriteria(valueSpecial1));
		assertTrue(value2.fitCriteria(valueSpecial2));
		assertTrue(value2.fitCriteria(valueSpecial3));
		assertTrue(value1.fitCriteria(valueTrue1));
		assertTrue(value1.fitCriteria(valueTrue2));
		assertTrue(value1.fitCriteria(valueTrue3));
		assertTrue(value1.fitCriteria(valueTrue4));
		assertTrue(value1.fitCriteria(valueTrue5));
		// Testing, direction 2
		assertFalse(valueFalse1.fitCriteria(value1));
		assertFalse(valueFalse2.fitCriteria(value1));
		assertFalse(valueSpecial1.fitCriteria(value1));
		assertFalse(valueSpecial2.fitCriteria(value1));
		assertFalse(valueSpecial3.fitCriteria(value1));
		assertTrue(valueSpecial1.fitCriteria(value2));
		assertTrue(valueSpecial2.fitCriteria(value2));
		assertTrue(valueSpecial3.fitCriteria(value2));
		assertTrue(valueTrue1.fitCriteria(value1));
		assertTrue(valueTrue2.fitCriteria(value1));
		assertTrue(valueTrue3.fitCriteria(value1));
		assertTrue(valueTrue4.fitCriteria(value1));
		assertTrue(valueTrue5.fitCriteria(value1));
	}
	
	@Test
	public void testBetweenIntFits(){
		IntegerValue value1 = new IntegerValue();
		IntegerValue value2 = new IntegerValue();
		value1.addBetween(0, 10);
		value2.addBetween(0, 10, false);
		// False Values
		IntegerValue valueFalse1 = new IntegerValue();
		valueFalse1.addBetween(11, 20);
		// Special Cases
		IntegerValue valueSpecial1 = new IntegerValue();
		IntegerValue valueSpecial2 = new IntegerValue();
		IntegerValue valueSpecial3 = new IntegerValue();
		IntegerValue valueSpecial4 = new IntegerValue();
		valueSpecial1.addBetween(-10, 0, true);
		valueSpecial2.addBetween(10, 20);
		valueSpecial3.addGreaterThan(10, true);
		valueSpecial4.addLessThan(0, true);
		// True Values
		IntegerValue valueTrue1 = new IntegerValue();
		IntegerValue valueTrue2 = new IntegerValue();
		IntegerValue valueTrue3 = new IntegerValue();
		IntegerValue valueTrue4 = new IntegerValue();
		IntegerValue valueTrue5 = new IntegerValue();
		IntegerValue valueTrue6 = new IntegerValue();
		valueTrue1.addLessThan(5);
		valueTrue2.addGreaterThan(5);
		valueTrue3.addBetween(-5, 5);
		valueTrue4.addBetween(5, 15);
		valueTrue5.addBetween(-5, 15);
		valueTrue6.addBetween(2, 8);
		// Testing, direction 1
		assertFalse(value1.fitCriteria(valueFalse1));
		assertTrue(value1.fitCriteria(valueSpecial1));
		assertTrue(value1.fitCriteria(valueSpecial2));
		assertTrue(value1.fitCriteria(valueSpecial3));
		assertTrue(value1.fitCriteria(valueSpecial4));
		assertFalse(value2.fitCriteria(valueSpecial1));
		assertFalse(value2.fitCriteria(valueSpecial2));
		assertFalse(value2.fitCriteria(valueSpecial3));
		assertFalse(value2.fitCriteria(valueSpecial4));
		assertTrue(value1.fitCriteria(valueTrue1));
		assertTrue(value1.fitCriteria(valueTrue2));
		assertTrue(value1.fitCriteria(valueTrue3));
		assertTrue(value1.fitCriteria(valueTrue4));
		assertTrue(value1.fitCriteria(valueTrue5));
		assertTrue(value1.fitCriteria(valueTrue6));
		// Testing, direction 2
		assertFalse(valueFalse1.fitCriteria(value1));
		assertTrue(valueSpecial1.fitCriteria(value1));
		assertTrue(valueSpecial2.fitCriteria(value1));
		assertTrue(valueSpecial3.fitCriteria(value1));
		assertTrue(valueSpecial4.fitCriteria(value1));
		assertFalse(valueSpecial1.fitCriteria(value2));
		assertFalse(valueSpecial2.fitCriteria(value2));
		assertFalse(valueSpecial3.fitCriteria(value2));
		assertFalse(valueSpecial4.fitCriteria(value2));
		assertTrue(valueTrue1.fitCriteria(value1));
		assertTrue(valueTrue2.fitCriteria(value1));
		assertTrue(valueTrue3.fitCriteria(value1));
		assertTrue(valueTrue4.fitCriteria(value1));
		assertTrue(valueTrue5.fitCriteria(value1));
		assertTrue(valueTrue6.fitCriteria(value1));
	}
	
	@Test
	public void testNotFits(){
		IntegerValue value1 = new IntegerValue();
		value1.addNot(0);
		// False
		IntegerValue valueFalse1 = new IntegerValue(0);
		// True
		IntegerValue valueTrue1 = new IntegerValue(1);
		IntegerValue valueTrue2 = new IntegerValue(1,10);
		IntegerValue valueTrue3 = new IntegerValue();
		IntegerValue valueTrue4 = new IntegerValue();
		valueTrue3.addNot(0);
		valueTrue4.addNot(1);
		// Testing
		assertFalse(value1.fitCriteria(valueFalse1));
		assertFalse(valueFalse1.fitCriteria(value1));
		assertTrue(value1.fitCriteria(valueTrue1));
		assertTrue(value1.fitCriteria(valueTrue2));
		assertTrue(value1.fitCriteria(valueTrue3));
		assertTrue(value1.fitCriteria(valueTrue4));
		assertTrue(valueTrue1.fitCriteria(value1));
		assertTrue(valueTrue2.fitCriteria(value1));
		assertTrue(valueTrue3.fitCriteria(value1));
		assertTrue(valueTrue4.fitCriteria(value1));
	}
}
