/*******************************************************************************
 * This file is part of Jake Todaro and Pragathi Balasubramanian's MQP.
 * Software Process Configurator MQP
 * Advised by Professor Gary Pollice
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jake Todaro
 *******************************************************************************/

package xmlParser;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

import booleanExpression.AndExpression;
import booleanExpression.NotExpression;
import booleanExpression.OrExpression;
import dialog.Answer;
import dialog.Dialog;
import dialog.SubDialog;

/** this test class tests that the SubDialogParser parses
 * triggers correctly. This class assumes correct input, and
 * does not check for malinput.
 * 
 * @author jake todaro
 * @version 12/21/11
 *
 */

public class TriggerParserTest {
	
	private static SubDialog subDialog1 = null;
	private static SubDialog subDialog2 = null;
	
	@BeforeClass
	public static void setup(){
		
		DialogParser.parseDialog("xmlDialogs/[DIALOG] testIndex.xml");
	
		subDialog1 = Dialog.getSubDialogList().get(0);
		subDialog2 = Dialog.getSubDialogList().get(1);	
	}
	
	@AfterClass
	public static void tearDown(){
		Dialog.close();
	}

	@Test
	public void testAnswerTrigger(){
		assertTrue(subDialog1.getQuestionList().get(1).getTrigger().equals(subDialog1.getQuestionList().get(0).getAnswerList().get(1)));
	}
	
	
	@Test
	public void testNotTrigger(){
		assertTrue(subDialog1.getQuestionList().get(3).getTrigger() instanceof NotExpression);
		NotExpression notTrigger = (NotExpression) subDialog1.getQuestionList().get(3).getTrigger();
		Answer notAnswer = (Answer) notTrigger.getAtom();
		assertTrue(notAnswer.equals(subDialog1.getQuestionList().get(2).getAnswerList().get(0)));
	}
	
	@Test
	public void testAndTrigger(){
		assertTrue(subDialog1.getQuestionList().get(4).getTrigger() instanceof AndExpression);
		AndExpression andTrigger = (AndExpression) subDialog1.getQuestionList().get(4).getTrigger();
		assertEquals(2, andTrigger.getAtomList().size());
		assertTrue(andTrigger.getAtomList().get(0).equals(subDialog1.getQuestionList().get(2).getAnswerList().get(3)));
		assertTrue(andTrigger.getAtomList().get(1).equals(subDialog1.getQuestionList().get(3).getAnswerList().get(1)));
	}
	
	@Test
	public void testOrTrigger(){
		assertTrue(subDialog1.getQuestionList().get(5).getTrigger() instanceof OrExpression);
		OrExpression orTrigger = (OrExpression) subDialog1.getQuestionList().get(5).getTrigger();
		assertEquals(2, orTrigger.getAtomList().size());
		assertTrue(orTrigger.getAtomList().get(0).equals(subDialog1.getQuestionList().get(4).getAnswerList().get(1)));
		assertTrue(orTrigger.getAtomList().get(1).equals(subDialog1.getQuestionList().get(3).getAnswerList().get(1)));
	}
	
	@Test
	public void testComplexAndTrigger(){
		assertTrue(subDialog1.getQuestionList().get(6).getTrigger() instanceof AndExpression);
		AndExpression andTrigger = (AndExpression) subDialog1.getQuestionList().get(6).getTrigger();
		assertEquals(2, andTrigger.getAtomList().size());
		assertTrue(andTrigger.getAtomList().get(0).equals(subDialog1.getQuestionList().get(2).getAnswerList().get(0)));
		assertTrue(andTrigger.getAtomList().get(1) instanceof NotExpression);
		NotExpression notTrigger = (NotExpression) andTrigger.getAtomList().get(1);
		assertTrue(notTrigger.getAtom().equals(subDialog1.getQuestionList().get(3).getAnswerList().get(0)));
	}
	
	
	@Test
	public void testReferencingQuestionTrigger(){
		assertTrue(subDialog2.getQuestionList().get(0).getTrigger().equals(subDialog1.getQuestionList().get(0).getAnswerList().get(1)));
	}

}
